@@ -23,15 +23,22 @@ from typing import List, Optional, cast
 from warnings import filterwarnings
 
 import click
-from aea.cli.utils.click_utils import reraise_as_click_exception
+from aea.cli.utils.click_utils import PublicIdParameter, reraise_as_click_exception
 from aea.cli.utils.context import Context
 from aea.cli.utils.decorators import pass_ctx
 from aea.configurations.constants import PACKAGES
+from aea.configurations.data_types import PublicId
 
-from autonomy.analyse.abci.logs import parse_file
 from autonomy.analyse.benchmark.aggregate import BlockTypes, aggregate
 from autonomy.analyse.handlers import check_handlers
-from autonomy.cli.helpers.analyse import list_all_skill_yaml_files, load_package_tree
+from autonomy.chain.config import ChainType
+from autonomy.cli.helpers.analyse import (
+    ParseLogs,
+    check_service_readiness,
+    list_all_skill_yaml_files,
+    load_package_tree,
+    run_dialogues_check,
+)
 from autonomy.cli.helpers.docstring import analyse_docstrings
 from autonomy.cli.helpers.fsm_spec import check_all as check_all_fsm
 from autonomy.cli.helpers.fsm_spec import check_one as check_one_fsm
@@ -39,10 +46,13 @@ from autonomy.cli.helpers.fsm_spec import update_one as update_one_fsm
 from autonomy.cli.utils.click_utils import (
     PathArgument,
     abci_spec_format_flag,
+    chain_selection_flag,
     sys_path_patch,
 )
+from autonomy.deploy.constants import LOGGING_LEVELS
 
 
+TIME_FORMAT_TEMPLATE = "YYYY-MM-DD H:M:S,MS"
 BENCHMARKS_DIR = Path("./benchmarks.html")
 
 filterwarnings("ignore")
@@ -156,13 +166,128 @@ def docstrings(ctx: Context, update: bool) -> None:
                 click.echo("No update needed.")
 
 
-@analyse_group.command(name="logs")
-@click.argument("file", type=click.Path(file_okay=True, dir_okay=False, exists=True))
-def parse_logs(file: str) -> None:
-    """Parse logs of an agent service."""
+@analyse_group.command("logs")
+@click.option(
+    "--from-dir",
+    "logs_dir",
+    type=click.Path(
+        exists=True,
+    ),
+    required=True,
+    help="Path to logs directory",
+)
+@click.option(
+    "--reset-db",
+    is_flag=True,
+    help="Use this flag to reset the log database.",
+)
+@click.option(
+    "-a",
+    "--agent",
+    "agents",
+    type=str,
+    multiple=True,
+    help="Agent IDs to include in analysis",
+)
+@click.option(
+    "--start-time",
+    type=str,
+    help=f"Start time in `{TIME_FORMAT_TEMPLATE}` format",
+)
+@click.option(
+    "--end-time",
+    type=str,
+    help=f"End time in `{TIME_FORMAT_TEMPLATE}` format",
+)
+@click.option(
+    "--log-level",
+    type=click.Choice(choices=LOGGING_LEVELS, case_sensitive=True),
+    help="Logging level.",
+)
+@click.option(
+    "--period",
+    type=int,
+    help="Period ID",
+)
+@click.option(
+    "--round",
+    "round_name",
+    type=str,
+    help="Round name",
+)
+@click.option(
+    "--behaviour",
+    "behaviour_name",
+    type=str,
+    help="Behaviour name filter",
+)
+@click.option(
+    "--fsm",
+    "fsm_path",
+    is_flag=True,
+    type=str,
+    help="Print only the FSM execution path",
+)
+@click.option(
+    "-ir",
+    "--include-regex",
+    "include_regexes",
+    multiple=True,
+    type=str,
+    help="Regex pattern to include in the result.",
+)
+@click.option(
+    "-er",
+    "--exclude-regex",
+    "exclude_regexes",
+    multiple=True,
+    type=str,
+    help="Regex pattern to exclude from the result.",
+)
+def _parse_logs(  # pylint: disable=too-many-arguments
+    logs_dir: Optional[Path],
+    agents: List[str],
+    start_time: Optional[str],
+    end_time: Optional[str],
+    log_level: Optional[str],
+    period: Optional[int],
+    round_name: Optional[str],
+    behaviour_name: Optional[str],
+    include_regexes: List[str],
+    exclude_regexes: List[str],
+    reset_db: bool = False,
+    fsm_path: bool = False,
+) -> None:
+    """A tool for analysing autonomous agent runtime logs"""
 
-    with reraise_as_click_exception(Exception):
-        parse_file(file)
+    parser = ParseLogs()
+    if logs_dir is not None:
+        parser.from_dir(logs_dir=Path(logs_dir))
+
+    if len(agents) == 0:
+        raise click.ClickException(
+            f"Please provide agent IDs to select logs; Available agents: {parser.agents}"
+        )
+
+    parser.create_tables(reset=reset_db)
+    selection = (
+        parser.select(
+            agents=agents,
+            start_time=start_time,
+            end_time=end_time,
+            log_level=log_level,
+            period=period,
+            round_name=round_name,
+            behaviour_name=behaviour_name,
+        )
+        .re_include(regexes=include_regexes)
+        .re_exclude(regexes=exclude_regexes)
+    )
+
+    if fsm_path:
+        return selection.execution_path()
+
+    return selection.table()
 
 
 @analyse_group.command(name="handlers")
@@ -209,6 +334,43 @@ def run_handler_check(
             )
 
 
+@analyse_group.command(name="dialogues")
+@pass_ctx
+@click.option(
+    "--dialogue",
+    "-d",
+    "dialogues",
+    type=str,
+    default=[
+        "abci",
+    ],
+    help="Specify which dialogues to check. Eg. -d dialogue_a -d dialogue_b -d dialogue_c",
+    multiple=True,
+)
+@click.option(
+    "--ignore",
+    "-i",
+    type=str,
+    default=[
+        "abstract_abci",
+    ],
+    help="Specify which skills to skip. Eg. -i skill_0 -i skill_1 -i skill_2",
+    multiple=True,
+)
+def _check_dialogues(
+    ctx: Context,
+    ignore: List[str],
+    dialogues: List[str],
+) -> None:
+    """Check dialogues definitions in a skill package."""
+
+    run_dialogues_check(
+        packages_dir=Path(ctx.registry_path),
+        ignore=ignore,
+        dialogues=dialogues,
+    )
+
+
 @analyse_group.command(name="benchmarks")
 @click.argument(
     "path",
@@ -240,3 +402,42 @@ def benchmark(path: Path, block_type: str, period: int, output: Path) -> None:
 
     with reraise_as_click_exception(Exception):
         aggregate(path=path, block_type=block_type, period=period, output=Path(output))
+
+
+@analyse_group.command(name="service")
+@click.option(
+    "--token-id",
+    type=int,
+    help="Token ID of the service",
+)
+@click.option(
+    "--public-id",
+    type=PublicIdParameter(),
+    help="Public ID of the service",
+)
+@chain_selection_flag()
+@pass_ctx
+def _check_service(
+    ctx: Context,
+    token_id: Optional[int],
+    public_id: Optional[PublicId],
+    chain_type: str,
+) -> None:
+    """Check deployment readiness of a service"""
+
+    if token_id is None and public_id is None:
+        raise click.ClickException(
+            "Please provide either the public ID or the on-chain token ID of of the service"
+        )
+
+    if token_id is not None and public_id is not None:
+        raise click.ClickException(
+            "Please provide either the public ID or the on-chain token ID of of the service, not both"
+        )
+
+    check_service_readiness(
+        token_id=token_id,
+        public_id=public_id,
+        chain_type=ChainType(chain_type),
+        packages_dir=Path(ctx.registry_path),
+    )
