@@ -9,9 +9,9 @@ fi
 echo Running the aea with $(aea --version)
 
 echo "Loading $AEA_AGENT"
-aea fetch $AEA_AGENT --alias agent
+aea fetch $AEA_AGENT --alias agent || exit 1
 cd agent
 
 echo "Installing the necessary dependencies!"
-aea install
+aea install || exit 1
 cd ..
\ No newline at end of file
