@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -38,6 +38,7 @@ from aea.configurations.data_types import PublicId
 
 from autonomy.configurations.base import Service
 from autonomy.configurations.loader import load_service_config
+from autonomy.constants import DEFAULT_DOCKER_IMAGE_AUTHOR
 from autonomy.deploy.constants import (
     DEFAULT_ENCODING,
     INFO,
@@ -49,7 +50,6 @@ from autonomy.deploy.constants import (
 ENV_VAR_ID = "ID"
 ENV_VAR_AEA_AGENT = "AEA_AGENT"
 ENV_VAR_ABCI_HOST = "ABCI_HOST"
-ENV_VAR_MAX_PARTICIPANTS = "MAX_PARTICIPANTS"
 ENV_VAR_TENDERMINT_URL = "TENDERMINT_URL"
 ENV_VAR_TENDERMINT_COM_URL = "TENDERMINT_COM_URL"
 ENV_VAR_LOG_LEVEL = "LOG_LEVEL"
@@ -58,6 +58,7 @@ ENV_VAR_AEA_PASSWORD = "AEA_PASSWORD"  # nosec
 SETUP_PARAM_PATH = ("models", "params", "args", "setup")
 SAFE_CONTRACT_ADDRESS = "safe_contract_address"
 ALL_PARTICIPANTS = "all_participants"
+CONSENSUS_THRESHOLD = "consensus_threshold"
 
 ABCI_HOST = "abci{}"
 TENDERMINT_NODE = "http://node{}:26657"
@@ -277,6 +278,7 @@ class ServiceBuilder:
         self,
         multisig_address: Optional[str] = None,
         agent_instances: Optional[List[str]] = None,
+        consensus_threshold: Optional[int] = None,
     ) -> None:
         """Try and update setup parameters."""
 
@@ -291,6 +293,11 @@ class ServiceBuilder:
                 (ALL_PARTICIPANTS, [agent_instances]),
             )
 
+        if consensus_threshold is not None:
+            param_overrides.append(
+                (CONSENSUS_THRESHOLD, [consensus_threshold]),
+            )
+
         overrides = copy(self.service.overrides)
         for override in overrides:
             (
@@ -343,7 +350,6 @@ class ServiceBuilder:
             ENV_VAR_ID: agent_n,
             ENV_VAR_AEA_AGENT: self.service.agent,
             ENV_VAR_ABCI_HOST: ABCI_HOST.format(agent_n),
-            ENV_VAR_MAX_PARTICIPANTS: self.service.number_of_agents,
             ENV_VAR_TENDERMINT_URL: TENDERMINT_NODE.format(agent_n),
             ENV_VAR_TENDERMINT_COM_URL: TENDERMINT_COM.format(agent_n),
             ENV_VAR_LOG_LEVEL: self.log_level,
@@ -371,7 +377,7 @@ class ServiceBuilder:
         return agent_vars
 
 
-class BaseDeploymentGenerator(abc.ABC):
+class BaseDeploymentGenerator(abc.ABC):  # pylint: disable=too-many-instance-attributes
     """Base Deployment Class."""
 
     service_builder: ServiceBuilder
@@ -381,6 +387,7 @@ class BaseDeploymentGenerator(abc.ABC):
     output: str
     tendermint_job_config: Optional[str]
     dev_mode: bool
+    use_tm_testnet_setup: bool
 
     packages_dir: Path
     open_aea_dir: Path
@@ -390,15 +397,18 @@ class BaseDeploymentGenerator(abc.ABC):
         self,
         service_builder: ServiceBuilder,
         build_dir: Path,
+        use_tm_testnet_setup: bool = False,
         dev_mode: bool = False,
         packages_dir: Optional[Path] = None,
         open_aea_dir: Optional[Path] = None,
         open_autonomy_dir: Optional[Path] = None,
+        image_author: Optional[str] = None,
     ):
         """Initialise with only kwargs."""
 
         self.service_builder = service_builder
         self.build_dir = build_dir
+        self.use_tm_testnet_setup = use_tm_testnet_setup
         self.dev_mode = dev_mode
         self.packages_dir = packages_dir or Path.cwd().absolute() / "packages"
         self.open_aea_dir = open_aea_dir or Path.home().absolute() / "open-aea"
@@ -407,6 +417,7 @@ class BaseDeploymentGenerator(abc.ABC):
         )
 
         self.tendermint_job_config: Optional[str] = None
+        self.image_author = image_author or DEFAULT_DOCKER_IMAGE_AUTHOR
 
     @abc.abstractmethod
     def generate(
