@@ -45,11 +45,14 @@ def generate_deployment(  # pylint: disable=too-many-arguments, too-many-locals
     open_autonomy_dir: Optional[Path] = None,
     agent_instances: Optional[List[str]] = None,
     multisig_address: Optional[str] = None,
+    consensus_threshold: Optional[int] = None,
     log_level: str = INFO,
     apply_environment_variables: bool = False,
     image_version: Optional[str] = None,
     use_hardhat: bool = False,
     use_acn: bool = False,
+    use_tm_testnet_setup: bool = False,
+    image_author: Optional[str] = None,
 ) -> str:
     """Generate the deployment for the service."""
 
@@ -65,6 +68,7 @@ def generate_deployment(  # pylint: disable=too-many-arguments, too-many-locals
     service_builder.try_update_runtime_params(
         multisig_address=multisig_address,
         agent_instances=agent_instances,
+        consensus_threshold=consensus_threshold,
     )
 
     DeploymentGenerator = DEPLOYMENT_OPTIONS[type_of_deployment]
@@ -75,6 +79,8 @@ def generate_deployment(  # pylint: disable=too-many-arguments, too-many-locals
         packages_dir=packages_dir,
         open_aea_dir=open_aea_dir,
         open_autonomy_dir=open_autonomy_dir,
+        use_tm_testnet_setup=use_tm_testnet_setup,
+        image_author=image_author,
     )
 
     (
