@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -56,6 +56,10 @@ from autonomy.deploy.generators.docker_compose.templates import (
 # and 192.167.11.3 so we will start from 192.167.11.4 for abci and tendermint nodes
 N_RESERVED_IP_ADDRESSES = 4
 
+DEFAULT_PACKAGES_PATH = Path.cwd().absolute() / "packages"
+DEFAULT_OPEN_AEA_DIR: Path = Path.home().absolute() / "open-aea"
+DEFAULT_OPEN_AUTONOMY_DIR: Path = Path.home().absolute() / "open-autonomy"
+
 
 def build_tendermint_node_config(
     node_id: int,
@@ -86,9 +90,9 @@ def build_agent_config(  # pylint: disable=too-many-arguments
     agent_vars: Dict,
     runtime_image: str,
     dev_mode: bool = False,
-    package_dir: Path = Path.cwd().absolute() / "packages",
-    open_aea_dir: Path = Path.home().absolute() / "open-aea",
-    open_autonomy_dir: Path = Path.home().absolute() / "open-autonomy",
+    package_dir: Path = DEFAULT_PACKAGES_PATH,
+    open_aea_dir: Path = DEFAULT_OPEN_AEA_DIR,
+    open_autonomy_dir: Path = DEFAULT_OPEN_AUTONOMY_DIR,
 ) -> str:
     """Build agent config."""
 
@@ -121,6 +125,9 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
     def generate_config_tendermint(self) -> "DockerComposeGenerator":
         """Generate the command to configure tendermint testnet."""
 
+        if not self.use_tm_testnet_setup:
+            return self
+
         hosts = (
             " \\\n".join(
                 [
@@ -157,6 +164,7 @@ class DockerComposeGenerator(BaseDeploymentGenerator):
             image_version = "dev"
 
         runtime_image = OAR_IMAGE.format(
+            image_author=self.image_author,
             agent=self.service_builder.service.agent.name,
             version=image_version,
         )
