@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -60,15 +60,19 @@ class KubernetesGenerator(BaseDeploymentGenerator):
         packages_dir: Optional[Path] = None,
         open_aea_dir: Optional[Path] = None,
         open_autonomy_dir: Optional[Path] = None,
+        use_tm_testnet_setup: bool = False,
+        image_author: Optional[str] = None,
     ) -> None:
         """Initialise the deployment generator."""
         super().__init__(
-            service_builder,
-            build_dir,
-            dev_mode,
-            packages_dir,
-            open_aea_dir,
-            open_autonomy_dir,
+            service_builder=service_builder,
+            build_dir=build_dir,
+            use_tm_testnet_setup=use_tm_testnet_setup,
+            dev_mode=dev_mode,
+            packages_dir=packages_dir,
+            open_aea_dir=open_aea_dir,
+            open_autonomy_dir=open_autonomy_dir,
+            image_author=image_author,
         )
         self.resources: List[str] = []
 
@@ -165,6 +169,7 @@ class KubernetesGenerator(BaseDeploymentGenerator):
         agent_vars = self.service_builder.generate_agents()  # type:ignore
         agent_vars = self._apply_cluster_specific_tendermint_params(agent_vars)
         runtime_image = OAR_IMAGE.format(
+            image_author=self.image_author,
             agent=self.service_builder.service.agent.name,
             version=image_version,
         )
@@ -189,7 +194,11 @@ class KubernetesGenerator(BaseDeploymentGenerator):
     ) -> "KubernetesGenerator":
         """Write output to build dir"""
 
-        output = "---\n".join([self.output, cast(str, self.tendermint_job_config)])
+        if self.use_tm_testnet_setup:
+            output = "---\n".join([self.output, cast(str, self.tendermint_job_config)])
+        else:
+            output = self.output
+
         if not self.build_dir.is_dir():  # pragma: no cover
             self.build_dir.mkdir()
         with open(
