@@ -85,6 +85,8 @@ class BaseHelloWorldABCITest(
     key_pairs = KEY_PAIRS
     strict_check_strings: Tuple[str, ...] = STRICT_CHECK_STRINGS
     package_registry_src_rel = Path(__file__).parent.parent.parent.parent.parent
+    ROUND_TIMEOUT_SECONDS = 30
+    OBSERVATION_INTERVAL = 10
 
 
 @pytest.mark.usefixtures(
