@@ -23,26 +23,13 @@
 import datetime
 import inspect
 import json
-import math
 import pprint
 import re
 import sys
 from abc import ABC, ABCMeta, abstractmethod
 from enum import Enum
 from functools import partial
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Generator,
-    List,
-    Optional,
-    OrderedDict,
-    Tuple,
-    Type,
-    Union,
-    cast,
-)
+from typing import Any, Callable, Dict, Generator, Optional, Tuple, Type, Union, cast
 
 import pytz
 from aea.exceptions import enforce
@@ -113,14 +100,10 @@ from packages.valory.skills.abstract_round_abci.models import (
 # TODO: port registration code from registration_abci to here
 
 
-MIN_HEIGHT_OFFSET = 10
-HEIGHT_OFFSET_MULTIPLIER = 1
 NON_200_RETURN_CODE_DURING_RESET_THRESHOLD = 3
 GENESIS_TIME_FMT = "%Y-%m-%dT%H:%M:%S.%fZ"
-ROOT_HASH = "726F6F743A3"
-RESET_HASH = "72657365743A3"
-APP_HASH_RE = rf"{ROOT_HASH}\d+{RESET_HASH}(\d+)"
 INITIAL_APP_HASH = ""
+INITIAL_HEIGHT = "0"
 TM_REQ_TIMEOUT = 5  # 5 seconds
 
 
@@ -304,7 +287,7 @@ class AsyncBehaviour(ABC):
         finally:
             self.__state = self.AsyncState.RUNNING
 
-    def setup(self) -> None:
+    def setup(self) -> None:  # noqa: B027  # flake8 suggest make it abstract
         """Setup behaviour."""
 
     def act(self) -> None:
@@ -746,40 +729,6 @@ class BaseBehaviour(
         if self._is_done:
             self._log_end()
 
-    def _sync_state(self, app_hash: str) -> None:
-        """
-        Sync the app's state using the given `app_hash`.
-
-        This method is intended for use after syncing local with remote.
-        The fact that we sync up with the blockchain does not mean that we also have the correct application state.
-        The application state is defined by the abci app's developer and also determines the generation of the app hash.
-        When we sync with the blockchain, it means that we no longer lag behind the other agents.
-        However, the application's state should also be updated, which is what this method takes care for.
-        We have chosen a simple application state for the time being,
-        which is a combination of the round count and the times we have reset so far.
-        The round count will be automatically updated by the framework while replaying the missed rounds,
-        however, the reset index needs to be manually updated.
-
-        Tendermint's block sync and state sync are not to be confused with our application's state;
-        they are different methods to sync faster with the blockchain.
-
-        :param app_hash: the app hash from which the state will be updated.
-        """
-        if app_hash == INITIAL_APP_HASH:
-            reset_index = 0
-        else:
-            match = re.match(APP_HASH_RE, app_hash)
-            if match is None:
-                raise ValueError(
-                    "Expected an app hash of the form: `726F6F743A3{ROUND_COUNT}72657365743A3{RESET_INDEX}`,"
-                    "which is derived from `root:{ROUND_COUNT}reset:{RESET_INDEX}`. "
-                    "For example, `root:90reset:4` would be `726F6F743A39072657365743A34`. "
-                    f"However, the app hash received is: `{app_hash}`."
-                )
-            reset_index = int(match.group(1))
-
-        self.context.state.round_sequence.abci_app.reset_index = reset_index
-
     def _check_sync(
         self,
     ) -> Generator[None, None, None]:
@@ -801,10 +750,6 @@ class BaseBehaviour(
                     self.context.logger.info(
                         f"local height == remote == {local_height}; Sync complete..."
                     )
-                    remote_app_hash = str(
-                        json_body["result"]["sync_info"]["latest_app_hash"]
-                    )
-                    self._sync_state(remote_app_hash)
                     self.context.state.round_sequence.end_sync()
                     return
                 yield from self.sleep(self.context.params.tendermint_check_sleep_delay)
@@ -1277,8 +1222,8 @@ class BaseBehaviour(
         method: str,
         url: str,
         content: Optional[bytes] = None,
-        headers: Optional[List[OrderedDict[str, str]]] = None,
-        parameters: Optional[List[Tuple[str, str]]] = None,
+        headers: Optional[Dict[str, str]] = None,
+        parameters: Optional[Dict[str, str]] = None,
     ) -> Generator[None, None, HttpMessage]:
         """
         Send an http request message from the skill context.
@@ -1344,8 +1289,8 @@ class BaseBehaviour(
         method: str,
         url: str,
         content: Optional[bytes] = None,
-        headers: Optional[List[OrderedDict[str, str]]] = None,
-        parameters: Optional[List[Tuple[str, str]]] = None,
+        headers: Optional[Dict[str, str]] = None,
+        parameters: Optional[Dict[str, str]] = None,
     ) -> Tuple[HttpMessage, HttpDialogue]:
         """
         Send an http request message from the skill context.
@@ -1362,15 +1307,14 @@ class BaseBehaviour(
         """
         if parameters:
             url = url + "?"
-            for key, val in parameters:
+            for key, val in parameters.items():
                 url += f"{key}={val}&"
             url = url[:-1]
 
         header_string = ""
         if headers:
-            for header in headers:
-                for key, val in header.items():
-                    header_string += f"{key}: {val}\r\n"
+            for key, val in headers.items():
+                header_string += f"{key}: {val}\r\n"
 
         # context
         http_dialogues = cast(HttpDialogues, self.context.http_dialogues)
@@ -1758,13 +1702,11 @@ class BaseBehaviour(
         :param performative: the ACN request performative.
         :return: the result that the majority of the agents sent. If majority cannot be reached, returns `None`.
         """
-        ourself = {self.context.agent_address}
+        shared_state = cast(SharedState, self.context.state)
         # reset the ACN deliverables at the beginning of a new request
-        addresses = self.synchronized_data.all_participants - ourself
-        cast(
-            SharedState, self.context.state
-        ).address_to_acn_deliverable = dict.fromkeys(addresses)
+        shared_state.address_to_acn_deliverable = shared_state.acn_container()
 
+        result = None
         for i in range(self.params.max_attempts):
             self.context.logger.debug(
                 f"ACN attempt {i + 1}/{self.params.max_attempts}."
@@ -1773,9 +1715,9 @@ class BaseBehaviour(
 
             result = cast(SharedState, self.context.state).get_acn_result()
             if result is not None:
-                return result
+                break
 
-        return None
+        return result
 
     def request_recovery_params(self) -> Generator[None, None, bool]:
         """Request the Tendermint recovery parameters from the other agents via the ACN."""
@@ -1856,7 +1798,7 @@ class BaseBehaviour(
             0, self._timeout
         )
 
-    def _get_reset_params(self, default: bool) -> Optional[List[Tuple[str, str]]]:
+    def _get_reset_params(self, default: bool) -> Optional[Dict[str, str]]:
         """Get the parameters for a hard reset request to Tendermint."""
         if default:
             return None
@@ -1867,24 +1809,11 @@ class BaseBehaviour(
         genesis_time = last_round_transition_timestamp.astimezone(pytz.UTC).strftime(
             GENESIS_TIME_FMT
         )
-        # Initial height needs to account for the asynchrony among agents.
-        # For that reason, we are using an offset in the initial block's height.
-        # The bigger the observation interval, the larger the lag among the agents might be.
-        # Also, if the observation interval is too tiny, we do not want the offset to be too small.
-        # Therefore, we choose between a minimum value and the interval multiplied by a constant.
-        # The larger the `HEIGHT_OFFSET_MULTIPLIER` constant's value, the larger the margin of error.
-        initial_height = str(
-            self.context.state.round_sequence.last_round_transition_tm_height
-            + max(
-                MIN_HEIGHT_OFFSET,
-                math.ceil(self.params.observation_interval * HEIGHT_OFFSET_MULTIPLIER),
-            )
-        )
-
-        return [
-            ("genesis_time", genesis_time),
-            ("initial_height", initial_height),
-        ]
+        return {
+            "genesis_time": genesis_time,
+            "initial_height": INITIAL_HEIGHT,
+            "period_count": str(self.synchronized_data.period_count),
+        }
 
     def reset_tendermint_with_wait(  # pylint: disable=too-many-locals, too-many-statements
         self,
@@ -1929,10 +1858,6 @@ class BaseBehaviour(
                         self.context.state.round_sequence.reset_blockchain(
                             is_replay=is_replay, is_init=True
                         )
-                    self.context.state.round_sequence.abci_app.cleanup(
-                        self.params.cleanup_history_depth,
-                        self.params.cleanup_history_depth_current,
-                    )
                     for handler_name in self.context.handlers.__dict__.keys():
                         dialogues = getattr(self.context, f"{handler_name}_dialogues")
                         dialogues.cleanup()
@@ -1941,21 +1866,20 @@ class BaseBehaviour(
                         # so that in the future if the communication with tendermint breaks, and we need to
                         # perform a hard reset to restore it, we can use these as the right ones
                         shared_state = cast(SharedState, self.context.state)
-                        # we take one from the reset index and round count because they are incremented
-                        # when resetting and scheduling rounds respectively
-                        reset_index = (
-                            shared_state.round_sequence.abci_app.reset_index - 1
-                        )
                         round_count = shared_state.synchronized_data.db.round_count - 1
                         # in case we need to reset in order to recover agent <-> tm communication
                         # we store this round as the one to start from
                         restart_from_round = self.matching_round
                         shared_state.tm_recovery_params = TendermintRecoveryParams(
                             reset_params=reset_params,
-                            reset_index=reset_index,
                             round_count=round_count,
                             reset_from_round=restart_from_round.auto_round_id(),
+                            serialized_db_state=shared_state.synchronized_data.db.serialize(),
                         )
+                    self.context.state.round_sequence.abci_app.cleanup(
+                        self.params.cleanup_history_depth,
+                        self.params.cleanup_history_depth_current,
+                    )
                     self._end_reset()
 
                 else:
@@ -2150,10 +2074,10 @@ class TmManager(BaseBehaviour):
         num_active_peers = yield from self.num_active_peers(timeout=TM_REQ_TIMEOUT)
         if (
             num_active_peers is not None
-            and num_active_peers < self.params.consensus_params.consensus_threshold
+            and num_active_peers < self.synchronized_data.consensus_threshold
         ):
             self.context.logger.error(
-                f"There should be at least {self.params.consensus_params.consensus_threshold} peers in the service,"
+                f"There should be at least {self.synchronized_data.consensus_threshold} peers in the service,"
                 f" only {num_active_peers} are currently active. Shutting down the agent."
             )
             not_ok_code = 1
@@ -2185,12 +2109,13 @@ class TmManager(BaseBehaviour):
         shared_state.round_sequence.reset_state(
             restart_from_round=recovery_params.reset_from_round,
             round_count=recovery_params.round_count,
-            reset_index=recovery_params.reset_index,
+            serialized_db_state=recovery_params.serialized_db_state,
         )
 
         for _ in range(self._max_reset_retry):
             reset_successfully = yield from self.reset_tendermint_with_wait(
-                is_recovery=True
+                on_startup=True,
+                is_recovery=True,
             )
             if reset_successfully:
                 self.context.logger.info(
@@ -2202,12 +2127,14 @@ class TmManager(BaseBehaviour):
                 # doesn't guarantee us this, since the block stall deadline is greater than the
                 # hard_reset_sleep, 60s vs 20s. In other words, we haven't received a block for at
                 # least 60s, so wait_from_last_timestamp() will return immediately.
+                # By setting "on_startup" to True in the reset_tendermint_with_wait() call above,
+                # wait_from_last_timestamp() will not be called at all.
                 yield from self.sleep(self.hard_reset_sleep)
                 return
 
         self.context.logger.info("Failed to reset tendermint.")
 
-    def _get_reset_params(self, default: bool) -> Optional[List[Tuple[str, str]]]:
+    def _get_reset_params(self, default: bool) -> Optional[Dict[str, str]]:
         """
         Get the parameters for a hard reset request when trying to recover agent <-> tendermint communication.
 
