@@ -31,15 +31,16 @@ from typing import (
     Any,
     Callable,
     Dict,
-    Iterable,
     List,
     Optional,
+    OrderedDict,
     Tuple,
     Type,
     cast,
     get_type_hints,
 )
 
+from aea.configurations.data_types import PublicId
 from aea.exceptions import enforce
 from aea.skills.base import Model, SkillContext
 
@@ -48,20 +49,20 @@ from packages.valory.skills.abstract_round_abci.base import (
     AbciApp,
     AbciAppDB,
     BaseSynchronizedData,
-    ConsensusParams,
-    RESET_INDEX_DEFAULT,
     ROUND_COUNT_DEFAULT,
     RoundSequence,
-    consensus_threshold,
     get_name,
 )
 from packages.valory.skills.abstract_round_abci.utils import (
+    check,
     check_type,
+    consensus_threshold,
     get_data_from_nested_dict,
     get_value_with_type,
 )
 
 
+MIN_OBSERVATION_INTERVAL = 10
 NUMBER_OF_RETRIES: int = 5
 DEFAULT_BACKOFF_FACTOR: float = 2.0
 DEFAULT_TYPE_NAME: str = "str"
@@ -264,8 +265,8 @@ class BaseParams(
         self.retry_timeout: int = self._ensure("retry_timeout", kwargs, int)
         self.retry_attempts: int = self._ensure("retry_attempts", kwargs, int)
         self.keeper_timeout: float = self._ensure("keeper_timeout", kwargs, float)
-        self.observation_interval: int = self._ensure(
-            "observation_interval", kwargs, int
+        self.observation_interval: int = self._ensure_gte(
+            "observation_interval", kwargs, int, min_value=MIN_OBSERVATION_INTERVAL
         )
         self.drand_public_key: str = self._ensure("drand_public_key", kwargs, str)
         self.tendermint_com_url: str = self._ensure("tendermint_com_url", kwargs, str)
@@ -278,9 +279,6 @@ class BaseParams(
         self.reset_tendermint_after: int = self._ensure(
             "reset_tendermint_after", kwargs, int
         )
-        self.consensus_params: ConsensusParams = ConsensusParams.from_json(
-            self._ensure("consensus", kwargs, dict)
-        )
         self.cleanup_history_depth: int = self._ensure(
             "cleanup_history_depth", kwargs, int
         )
@@ -303,24 +301,10 @@ class BaseParams(
             "share_tm_config_on_startup", kwargs, bool
         )
         self.tendermint_p2p_url: str = self._ensure("tendermint_p2p_url", kwargs, str)
-        setup_params_: Dict[str, Any] = self._ensure("setup", kwargs, dict)
-
-        def check_val(val: Any, skill_id: str) -> List[Any]:
-            """Check that a value a list"""
-            if not isinstance(val, list):
-                raise TypeError(
-                    f"Value `{val}` in `setup` set in `models.params.args` of `skill.yaml` of `{skill_id}` is not a list"
-                )
-            return val
+        self.setup_params: Dict[str, Any] = self._ensure("setup", kwargs, dict)
 
         # we sanitize for null values as these are just kept for schema definitions
         skill_id = kwargs["skill_context"].skill_id
-        setup_params: Dict[str, List[Any]] = {
-            key: check_val(val, skill_id)
-            for key, val in setup_params_.items()
-            if val is not None
-        }
-        self.setup_params = setup_params
         super().__init__(*args, **kwargs)
 
         if not self.context.is_abstract_component:
@@ -328,19 +312,51 @@ class BaseParams(
             # and they should always contain at least `all_participants` and `safe_contract_address`
             self._ensure_setup(
                 {
-                    get_name(BaseSynchronizedData.safe_contract_address),
-                    get_name(BaseSynchronizedData.all_participants),
-                }
+                    get_name(BaseSynchronizedData.safe_contract_address): List[str],
+                    get_name(BaseSynchronizedData.all_participants): List[List[str]],
+                    get_name(BaseSynchronizedData.consensus_threshold): List[
+                        Optional[int]
+                    ],
+                },
+                skill_id,
             )
         self._frozen = True
 
-    def _ensure_setup(self, necessary_keys: Iterable[str]) -> Any:
-        """Ensure that the `setup` params contain all the `necessary_keys`."""
+    def _ensure_setup(
+        self, necessary_params: Dict[str, Type], skill_id: PublicId
+    ) -> Any:
+        """Ensure that the `setup` params contain all the `necessary_keys` and have the correct types."""
         enforce(bool(self.setup_params), "`setup` params contain no values!")
-        not_found_keys = set(necessary_keys) - set(self.setup_params)
-        found = not not_found_keys
-        fail_msg = f"Values for `{not_found_keys}` missing from the `setup` params."
-        enforce(found, fail_msg)
+
+        for key, type_ in necessary_params.items():
+            value = self.setup_params.get(key, None)
+            if value is None:
+                fail_msg = f"Value for `{key}` missing from the `setup` params."
+                enforce(False, fail_msg)
+
+            try:
+                check_type(key, value, type_)
+            except TypeError:  # pragma: nocover
+                enforce(
+                    False,
+                    f"'{key}' must be a {type_}, but type {type(value)} was found in `models.params.args.setup` "
+                    f"of `skill.yaml` of `{skill_id}`",
+                )
+
+    def _ensure_gte(
+        self, key: str, kwargs: Dict[str, Any], type_: Type, min_value: Any
+    ) -> Any:
+        """Ensure that the value for the key is greater than or equal to the provided min_value."""
+        err = check(min_value, type_)
+        enforce(
+            err is None,
+            f"min_value must be of type {type_.__name__}, but got {type(min_value).__name__}.",
+        )
+        value = self._ensure(key, kwargs, type_)
+        enforce(
+            value >= min_value, f"`{key}` must be greater than or equal to {min_value}."
+        )
+        return value
 
 
 class _MetaSharedState(ABCMeta):
@@ -397,6 +413,9 @@ class SharedState(Model, ABC, metaclass=_MetaSharedState):  # type: ignore
         """Initialize the state."""
         self.abci_app_cls._is_abstract = skill_context.is_abstract_component
         self._round_sequence: Optional[RoundSequence] = None
+        # a mapping of the agents' addresses to their initial Tendermint configuration, to be retrieved via ACN
+        self.initial_tm_configs: Dict[str, Optional[Dict[str, Any]]] = {}
+        # a mapping of the other agents' addresses to ACN deliverables
         self.address_to_acn_deliverable: Dict[str, Any] = {}
         self.tm_recovery_params: TendermintRecoveryParams = TendermintRecoveryParams(
             self.abci_app_cls.initial_round_cls.auto_round_id()
@@ -404,10 +423,16 @@ class SharedState(Model, ABC, metaclass=_MetaSharedState):  # type: ignore
         kwargs["skill_context"] = skill_context
         super().__init__(*args, **kwargs)
 
+    def acn_container(self) -> Dict[str, Any]:
+        """Create a container for ACN results, i.e., a mapping from others' addresses to `None`."""
+        ourself = {self.context.agent_address}
+        others_addresses = self.synchronized_data.all_participants - ourself
+
+        return dict.fromkeys(others_addresses)
+
     def setup(self) -> None:
         """Set up the model."""
         self._round_sequence = RoundSequence(self.abci_app_cls)
-        consensus_params = cast(BaseParams, self.context.params).consensus_params
         setup_params = cast(BaseParams, self.context.params).setup_params
         self.round_sequence.setup(
             BaseSynchronizedData(
@@ -416,9 +441,12 @@ class SharedState(Model, ABC, metaclass=_MetaSharedState):  # type: ignore
                     cross_period_persisted_keys=self.abci_app_cls.cross_period_persisted_keys,
                 )
             ),
-            consensus_params,
             self.context.logger,
         )
+        if not self.context.is_abstract_component:
+            self.initial_tm_configs = dict.fromkeys(
+                self.synchronized_data.all_participants
+            )
 
     @property
     def round_sequence(self) -> RoundSequence:
@@ -515,20 +543,30 @@ class RetriesInfo(TypeCheckMixin):
     @property
     def suggested_sleep_time(self) -> float:
         """The suggested amount of time to sleep."""
-        return self.backoff_factor ** self.retries_attempted
+        return self.backoff_factor**self.retries_attempted
 
 
 @dataclass(frozen=True)
 class TendermintRecoveryParams(TypeCheckMixin):
-    """A dataclass to hold all parameters related to agent <-> tendermint recovery procedures.
+    """
+    A dataclass to hold all parameters related to agent <-> tendermint recovery procedures.
 
     This must be frozen so that we make sure it does not get edited.
     """
 
     reset_from_round: str
     round_count: int = ROUND_COUNT_DEFAULT
-    reset_index: int = RESET_INDEX_DEFAULT
-    reset_params: Optional[List[Tuple[str, str]]] = None
+    reset_params: Optional[Dict[str, str]] = None
+    serialized_db_state: Optional[str] = None
+
+    def __hash__(self) -> int:
+        """Hash the object."""
+        return hash(
+            self.reset_from_round
+            + str(self.round_count)
+            + str(self.serialized_db_state)
+            + json.dumps(self.reset_params, sort_keys=True)
+        )
 
 
 class ApiSpecs(Model, FrozenMixin, TypeCheckMixin):
@@ -539,11 +577,11 @@ class ApiSpecs(Model, FrozenMixin, TypeCheckMixin):
         self.url: str = self._ensure("url", kwargs, str)
         self.api_id: str = self._ensure("api_id", kwargs, str)
         self.method: str = self._ensure("method", kwargs, str)
-        self.headers: List[Tuple[str, str]] = self._ensure(
-            "headers", kwargs, List[Tuple[str, str]]
+        self.headers: Dict[str, str] = dict(
+            self._ensure("headers", kwargs, OrderedDict[str, str])
         )
-        self.parameters: List[Tuple[str, str]] = self._ensure(
-            "parameters", kwargs, List[Tuple[str, str]]
+        self.parameters: Dict[str, str] = dict(
+            self._ensure("parameters", kwargs, OrderedDict[str, str])
         )
         self.response_info = ResponseInfo.from_json_dict(kwargs)
         self.retries_info = RetriesInfo.from_json_dict(kwargs)
