@@ -18,8 +18,10 @@
 # ------------------------------------------------------------------------------
 
 """Test the base.py module of the skill."""
+
 import dataclasses
 import datetime
+import json
 import logging
 import re
 import shutil
@@ -27,7 +29,6 @@ from abc import ABC
 from contextlib import suppress
 from copy import copy, deepcopy
 from dataclasses import dataclass
-from enum import Enum
 from pathlib import Path
 from time import sleep
 from typing import Any, Dict, Generator, List, Optional, Set, Tuple, Type
@@ -50,6 +51,7 @@ from hypothesis.strategies import (
     text,
 )
 
+import packages.valory.skills.abstract_round_abci.base as abci_base
 from packages.valory.connections.abci.connection import MAX_READ_IN_BYTES
 from packages.valory.skills.abstract_round_abci.base import (
     ABCIAppException,
@@ -66,7 +68,7 @@ from packages.valory.skills.abstract_round_abci.base import (
     Block,
     BlockBuilder,
     Blockchain,
-    ConsensusParams,
+    CollectionRound,
     EventType,
     LateArrivingTransaction,
     RoundSequence,
@@ -77,9 +79,8 @@ from packages.valory.skills.abstract_round_abci.base import (
     _MetaAbciApp,
     _MetaAbstractRound,
     _MetaPayload,
+    get_name,
 )
-from packages.valory.skills.abstract_round_abci.base import _logger as default_logger
-from packages.valory.skills.abstract_round_abci.base import get_name
 from packages.valory.skills.abstract_round_abci.test_tools.abci_app import (
     AbciAppTest,
     ConcreteBackgroundRound,
@@ -118,30 +119,6 @@ def hypothesis_cleanup() -> Generator:
             shutil.rmtree(hypothesis_dir)
 
 
-class PayloadEnum(Enum):
-    """Payload enumeration type."""
-
-    A = "A"
-    B = "B"
-    C = "C"
-    DUMMY = "DUMMY"
-    TOO_BIG_TO_FIT_IN_HERE = "TOO_BIG_TO_FIT_IN_HERE"
-
-    def __str__(self) -> str:
-        """Get the string representation."""
-        return self.value
-
-
-class PayloadEnumB(Enum):
-    """Payload enumeration type."""
-
-    A = "AA"
-
-    def __str__(self) -> str:
-        """Get the string representation."""
-        return self.value
-
-
 class BasePayload(BaseTxPayload, ABC):
     """Base payload class for testing."""
 
@@ -177,7 +154,7 @@ class DummyPayload(BasePayload):
 class TooBigPayload(BaseTxPayload):
     """Base payload class for testing."""
 
-    dummy_field: str = "0" * 10 ** 7
+    dummy_field: str = "0" * 10**7
 
 
 class ObjectImitator:
@@ -230,12 +207,6 @@ def test_abstract_round_instantiation_without_attributes_raises_error() -> None:
         class MyRoundBehaviourB(AbstractRound):
             synchronized_data_class = MagicMock()
 
-    with pytest.raises(AbstractRoundInternalError):
-
-        class MyRoundBehaviourC(AbstractRound):
-            synchronized_data_class = MagicMock()
-            payload_class = MagicMock()
-
 
 class TestTransactions:
     """Test Transactions class."""
@@ -458,60 +429,12 @@ class TestBlockBuilder:
         self.block_builder.get_block()
 
 
-class TestConsensusParams:
-    """Test the 'ConsensusParams' class."""
-
-    def setup(self) -> None:
-        """Set up the tests."""
-        self.max_participants = 4
-        self.consensus_params = ConsensusParams(self.max_participants)
-
-    def test_max_participants_getter(self) -> None:
-        """Test 'max_participants' property getter."""
-        expected_max_participants = self.max_participants
-        assert self.consensus_params.max_participants == expected_max_participants
-
-    @pytest.mark.parametrize(
-        "nb_participants,expected",
-        [
-            (1, 1),
-            (2, 2),
-            (3, 3),
-            (4, 3),
-            (5, 4),
-            (6, 5),
-            (7, 5),
-            (8, 6),
-            (9, 7),
-            (10, 7),
-        ],
-    )
-    def test_threshold_getter(self, nb_participants: int, expected: int) -> None:
-        """Test threshold property getter."""
-        params = ConsensusParams(nb_participants)
-        assert params.consensus_threshold == expected
-
-    def test_consensus_params_not_equal_lookalike(self) -> None:
-        """Test consensus param __eq__ reflection via NotImplemented"""
-        lookalike = ObjectImitator(self.consensus_params)
-        assert not self.consensus_params == lookalike
-
-    def test_from_json(self) -> None:
-        """Test 'from_json' method."""
-        expected = ConsensusParams(self.max_participants)
-        json_object = dict(
-            max_participants=self.max_participants,
-        )
-        actual = ConsensusParams.from_json(json_object)
-        assert expected == actual
-
-
 class TestAbciAppDB:
     """Test 'AbciAppDB' class."""
 
     def setup(self) -> None:
         """Set up the tests."""
-        self.participants = {"a", "b"}
+        self.participants = ("a", "b")
         self.db = AbciAppDB(
             setup_data=dict(participants=[self.participants]),
         )
@@ -531,13 +454,13 @@ class TestAbciAppDB:
     )
     @pytest.mark.parametrize(
         "cross_period_persisted_keys, expected_cross_period_persisted_keys",
-        ((None, []), ([], []), (["test"], ["test"])),
+        ((None, set()), (set(), set()), ({"test"}, {"test"})),
     )
     def test_init(
         self,
         data: Dict,
         setup_data: Optional[Dict],
-        cross_period_persisted_keys: Optional[List],
+        cross_period_persisted_keys: Optional[Set],
         expected_cross_period_persisted_keys: List,
     ) -> None:
         """Test constructor."""
@@ -580,7 +503,7 @@ class TestAbciAppDB:
         data_assertion()
 
         if cross_period_persisted_keys_copy:
-            cross_period_persisted_keys_copy.append(new_value_attempt)
+            cross_period_persisted_keys_copy.add(new_value_attempt)
             assert (
                 db.cross_period_persisted_keys == expected_cross_period_persisted_keys
             ), (
@@ -588,6 +511,13 @@ class TestAbciAppDB:
                 "by updating an item passed via the `__init__`!"
             )
 
+    @pytest.mark.parametrize("data", {0: [{"test": 2}]})
+    def test_reset_index(self, data: Dict) -> None:
+        """Test `reset_index`."""
+        assert self.db.reset_index == 0
+        self.db.sync(self.db.serialize())
+        assert self.db.reset_index == 0
+
     def test_round_count_setter(self) -> None:
         """Tests the round count setter."""
         expected_value = 1
@@ -623,10 +553,10 @@ class TestAbciAppDB:
     def test_cross_period_persisted_keys(self) -> None:
         """Test `cross_period_persisted_keys` property"""
         setup_data: Dict[str, List] = {}
-        cross_period_persisted_keys = ["test"]
+        cross_period_persisted_keys = {"test"}
         db = AbciAppDB(setup_data, cross_period_persisted_keys.copy())
 
-        db.cross_period_persisted_keys.append("new_value_attempt")
+        db.cross_period_persisted_keys.add("new_value_attempt")
         assert db.cross_period_persisted_keys == cross_period_persisted_keys, (
             "The database's `cross_period_persisted_keys` have been altered indirectly, "
             "by updating an item retrieved via the `cross_period_persisted_keys` property!"
@@ -670,6 +600,24 @@ class TestAbciAppDB:
         self.db.increment_round_count()
         assert self.db.round_count == 0
 
+    @mock.patch.object(
+        abci_base,
+        "is_json_serializable",
+        return_value=False,
+    )
+    def test_validate(self, _: mock._patch) -> None:
+        """Test `validate` method."""
+        data = "does not matter"
+
+        with pytest.raises(
+            ABCIAppInternalError,
+            match=re.escape(
+                "internal error: `AbciAppDB` data must be json-serializable. Please convert non-serializable data in "
+                f"`{data}`. You may use `AbciAppDB.validate(your_data)` to validate your data for the `AbciAppDB`."
+            ),
+        ):
+            AbciAppDB.validate(data)
+
     @pytest.mark.parametrize(
         "setup_data, update_data, expected_data",
         (
@@ -891,20 +839,64 @@ class TestAbciAppDB:
         db.cleanup(cleanup_history_depth, cleanup_history_depth_current)
         assert db._data == expected
 
+    def test_serialize(self) -> None:
+        """Test `serialize` method."""
+        assert self.db.serialize() == '{"0": {"participants": [["a", "b"]]}}'
+
+    @pytest.mark.parametrize("data", ({0: {"test": [0]}},))
+    def test_sync(self, data: Dict[int, Dict[str, List[Any]]]) -> None:
+        """Test `sync` method."""
+        try:
+            serialized_data = json.dumps(data)
+        except TypeError as exc:
+            raise AssertionError(
+                "Incorrectly parametrized test. Data must be json serializable."
+            ) from exc
+
+        self.db.sync(serialized_data)
+        assert self.db._data == data
+
+    @pytest.mark.parametrize(
+        "serialized_data, match",
+        (
+            (b"", "Could not decode data using "),
+            (
+                json.dumps({"invalid_index": {}}),
+                "An invalid index was found while trying to sync the db using data: ",
+            ),
+            (
+                json.dumps("invalid"),
+                "Could not decode db data with an invalid format: ",
+            ),
+        ),
+    )
+    def test_sync_incorrect_data(self, serialized_data: Any, match: str) -> None:
+        """Test `sync` method with incorrect data."""
+        with pytest.raises(
+            ABCIAppInternalError,
+            match=match,
+        ):
+            self.db.sync(serialized_data)
+
+    def test_hash(self) -> None:
+        """Test `hash` method."""
+        expected_hash = b"\x89j\xd8\xf7\x9b\x98>\x97b|\xbeI~y\x8b\x9a\xba\x92\xd4I\x05 \xe8\xc9\xcaQ\x80\xbf{:\xef\xc2"
+        assert self.db.hash() == expected_hash
+
 
 class TestBaseSynchronizedData:
     """Test 'BaseSynchronizedData' class."""
 
     def setup(self) -> None:
         """Set up the tests."""
-        self.participants = {"a", "b"}
+        self.participants = ("a", "b")
         self.base_synchronized_data = BaseSynchronizedData(
             db=AbciAppDB(setup_data=dict(participants=[self.participants]))
         )
 
     def test_participants_getter_positive(self) -> None:
         """Test 'participants' property getter."""
-        assert self.participants == self.base_synchronized_data.participants
+        assert frozenset(self.participants) == self.base_synchronized_data.participants
 
     def test_nb_participants_getter(self) -> None:
         """Test 'participants' property getter."""
@@ -924,21 +916,21 @@ class TestBaseSynchronizedData:
 
     def test_update(self) -> None:
         """Test the 'update' method."""
-        participants = {"a"}
+        participants = ("a",)
         expected = BaseSynchronizedData(
             db=AbciAppDB(setup_data=dict(participants=[participants]))
         )
         actual = self.base_synchronized_data.update(participants=participants)
         assert expected.participants == actual.participants
-        assert actual.db._data == {0: {"participants": [{"a", "b"}, {"a"}]}}
+        assert actual.db._data == {0: {"participants": [("a", "b"), ("a",)]}}
 
     def test_create(self) -> None:
         """Test the 'create' method."""
-        participants = {"a"}
+        participants = ("a",)
         actual = self.base_synchronized_data.create(participants=[participants])
         assert actual.db._data == {
-            0: {"participants": [{"a", "b"}]},
-            1: {"participants": [{"a"}]},
+            0: {"participants": [("a", "b")]},
+            1: {"participants": [("a",)]},
         }
 
     def test_repr(self) -> None:
@@ -952,7 +944,7 @@ class TestBaseSynchronizedData:
     ) -> None:
         """Tets when participants list is set to zero."""
         base_synchronized_data = BaseSynchronizedData(
-            db=AbciAppDB(setup_data=dict(participants=[{}]))
+            db=AbciAppDB(setup_data=dict(participants=[tuple()]))
         )
         with pytest.raises(ValueError, match="List participants cannot be empty."):
             _ = base_synchronized_data.participants
@@ -962,11 +954,75 @@ class TestBaseSynchronizedData:
     ) -> None:
         """Tets when participants list is set to zero."""
         base_synchronized_data = BaseSynchronizedData(
-            db=AbciAppDB(setup_data=dict(all_participants=[{}]))
+            db=AbciAppDB(setup_data=dict(all_participants=[tuple()]))
         )
         with pytest.raises(ValueError, match="List participants cannot be empty."):
             _ = base_synchronized_data.all_participants
 
+    @pytest.mark.parametrize(
+        "n_participants, given_threshold, expected_threshold",
+        (
+            (1, None, 1),
+            (5, None, 4),
+            (10, None, 7),
+            (345, None, 231),
+            (246236, None, 164158),
+            (1, 1, 1),
+            (5, 5, 5),
+            (10, 7, 7),
+            (10, 8, 8),
+            (10, 9, 9),
+            (10, 10, 10),
+            (345, 300, 300),
+            (246236, 194158, 194158),
+        ),
+    )
+    def test_consensus_threshold(
+        self, n_participants: int, given_threshold: int, expected_threshold: int
+    ) -> None:
+        """Test the `consensus_threshold` property."""
+        base_synchronized_data = BaseSynchronizedData(
+            db=AbciAppDB(
+                setup_data=dict(
+                    all_participants=[tuple(range(n_participants))],
+                    consensus_threshold=[given_threshold],
+                )
+            )
+        )
+
+        assert base_synchronized_data.consensus_threshold == expected_threshold
+
+    @pytest.mark.parametrize(
+        "n_participants, given_threshold",
+        (
+            (1, 2),
+            (5, 2),
+            (10, 4),
+            (10, 11),
+            (10, 18),
+            (345, 200),
+            (246236, 164157),
+            (246236, 246237),
+        ),
+    )
+    def test_consensus_threshold_incorrect(
+        self,
+        n_participants: int,
+        given_threshold: int,
+    ) -> None:
+        """Test the `consensus_threshold` property when an incorrect threshold value has been inserted to the db."""
+        base_synchronized_data = BaseSynchronizedData(
+            db=AbciAppDB(
+                setup_data=dict(
+                    all_participants=[tuple(range(n_participants))],
+                    consensus_threshold=[given_threshold],
+                )
+            )
+        )
+
+        with pytest.raises(ValueError, match="Consensus threshold "):
+            _ = base_synchronized_data.consensus_threshold
+
     def test_properties(self) -> None:
         """Test several properties"""
         participants = ["b", "a"]
@@ -976,9 +1032,9 @@ class TestBaseSynchronizedData:
         randomness_value = 0.20400769574270503
         most_voted_keeper_address = "most_voted_keeper_address"
         blacklisted_keepers = "blacklisted_keepers"
-        participant_to_selection = "participant_to_selection"
-        participant_to_randomness = "participant_to_randomness"
-        participant_to_votes = "participant_to_votes"
+        participant_to_selection = participant_to_randomness = participant_to_votes = {
+            "sender": DummyPayload(sender="sender", dummy_attribute=0)
+        }
         safe_contract_address = "0x0"
 
         base_synchronized_data = BaseSynchronizedData(
@@ -990,9 +1046,15 @@ class TestBaseSynchronizedData:
                         most_voted_randomness=randomness_str,
                         most_voted_keeper_address=most_voted_keeper_address,
                         blacklisted_keepers=blacklisted_keepers,
-                        participant_to_selection=participant_to_selection,
-                        participant_to_randomness=participant_to_randomness,
-                        participant_to_votes=participant_to_votes,
+                        participant_to_selection=CollectionRound.serialize_collection(
+                            participant_to_selection
+                        ),
+                        participant_to_randomness=CollectionRound.serialize_collection(
+                            participant_to_randomness
+                        ),
+                        participant_to_votes=CollectionRound.serialize_collection(
+                            participant_to_votes
+                        ),
                         safe_contract_address=safe_contract_address,
                     )
                 )
@@ -1001,6 +1063,7 @@ class TestBaseSynchronizedData:
         assert self.base_synchronized_data.period_count == 0
         assert base_synchronized_data.all_participants == frozenset(participants)
         assert base_synchronized_data.sorted_participants == ["a", "b"]
+        assert base_synchronized_data.max_participants == len(participants)
         assert abs(base_synchronized_data.keeper_randomness - randomness_value) < 1e-10
         assert base_synchronized_data.most_voted_randomness == randomness_str
         assert (
@@ -1020,63 +1083,52 @@ class TestBaseSynchronizedData:
         assert base_synchronized_data.safe_contract_address == safe_contract_address
 
 
+class DummyConcreteRound(AbstractRound):
+    """A dummy concrete round's implementation."""
+
+    payload_class: Optional[Type[BaseTxPayload]] = None
+    synchronized_data_class = MagicMock()
+    payload_attribute = MagicMock()
+
+    def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
+        """A dummy `end_block` implementation."""
+
+    def check_payload(self, payload: BaseTxPayload) -> None:
+        """A dummy `check_payload` implementation."""
+
+    def process_payload(self, payload: BaseTxPayload) -> None:
+        """A dummy `process_payload` implementation."""
+
+
 class TestAbstractRound:
     """Test the 'AbstractRound' class."""
 
     def setup(self) -> None:
         """Set up the tests."""
         self.known_payload_type = ConcreteRoundA.payload_class
-        self.participants = {"a", "b"}
+        self.participants = ("a", "b")
         self.base_synchronized_data = BaseSynchronizedData(
-            db=AbciAppDB(setup_data=dict(participants=[self.participants]))
+            db=AbciAppDB(
+                setup_data=dict(
+                    all_participants=[self.participants],
+                    participants=[self.participants],
+                    consensus_threshold=[2],
+                )
+            )
         )
-        self.params = ConsensusParams(
-            max_participants=len(self.participants),
-        )
-        self.round = ConcreteRoundA(self.base_synchronized_data, self.params)
+        self.round = ConcreteRoundA(self.base_synchronized_data)
 
     def test_auto_round_id(self) -> None:
         """Test that the 'auto_round_id()' method works as expected."""
 
-        class MyConcreteRound(AbstractRound):
-
-            payload_class = MagicMock()
-            synchronized_data_class = MagicMock()
-            payload_attribute = MagicMock()
-
-            def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
-                pass
-
-            def check_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def process_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-        assert MyConcreteRound.auto_round_id() == "my_concrete_round"
+        assert DummyConcreteRound.auto_round_id() == "dummy_concrete_round"
 
     def test_must_not_set_round_id(self) -> None:
         """Test that the 'round_id' must be set in concrete classes."""
 
-        class MyConcreteRound(AbstractRound):
-            # here round_id is missing
-            # ...
-            payload_class = MagicMock()
-            synchronized_data_class = MagicMock()
-            payload_attribute = MagicMock()
-
-            def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
-                pass
-
-            def check_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def process_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
         # no exception as round id is auto-assigned
-        my_concrete_round = MyConcreteRound(MagicMock(), MagicMock())
-        assert my_concrete_round.round_id == "my_concrete_round"
+        my_concrete_round = DummyConcreteRound(MagicMock())
+        assert my_concrete_round.round_id == "dummy_concrete_round"
 
     def test_must_set_payload_class_type(self) -> None:
         """Test that the 'payload_class' must be set in concrete classes."""
@@ -1090,71 +1142,33 @@ class TestAbstractRound:
                 synchronized_data_class = MagicMock()
                 payload_attribute = MagicMock()
                 # here payload_class is missing
-                # ...
-
-                def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
-                    pass
-
-                def check_payload(self, payload: BaseTxPayload) -> None:
-                    pass
-
-                def process_payload(self, payload: BaseTxPayload) -> None:
-                    pass
 
     def test_check_payload_type_with_previous_round_transaction(self) -> None:
         """Test check 'check_payload_type'."""
 
-        class MyConcreteRound(AbstractRound):
+        class MyConcreteRound(DummyConcreteRound):
+            """A concrete round with the payload class defined."""
 
             payload_class = BaseTxPayload
-            synchronized_data_class = MagicMock()
-            payload_attribute = MagicMock()
 
-            def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
-                pass
-
-            def check_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def process_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-        with pytest.raises(LateArrivingTransaction), mock.patch.object(
-            default_logger, "debug"
-        ) as mock_logger:
-            MyConcreteRound(MagicMock(), MagicMock(), BaseTxPayload).check_payload_type(
+        with pytest.raises(LateArrivingTransaction):
+            MyConcreteRound(MagicMock(), BaseTxPayload).check_payload_type(
                 MagicMock(payload=BaseTxPayload("dummy"))
             )
-            mock_logger.assert_called()
 
     def test_check_payload_type(self) -> None:
         """Test check 'check_payload_type'."""
 
-        class MyConcreteRound(AbstractRound):
-
-            payload_class = None
-            synchronized_data_class = MagicMock()
-            payload_attribute = MagicMock()
-
-            def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
-                pass
-
-            def check_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def process_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
         with pytest.raises(
             TransactionTypeNotRecognizedError,
             match="current round does not allow transactions",
         ):
-            MyConcreteRound(MagicMock(), MagicMock()).check_payload_type(MagicMock())
+            DummyConcreteRound(MagicMock()).check_payload_type(MagicMock())
 
     def test_synchronized_data_getter(self) -> None:
         """Test 'synchronized_data' property getter."""
         state = self.round.synchronized_data
-        assert state.participants == self.participants
+        assert state.participants == frozenset(self.participants)
 
     def test_check_transaction_unknown_payload(self) -> None:
         """Test 'check_transaction' method, with unknown payload type."""
@@ -1208,11 +1222,13 @@ class TestAbstractRound:
             ABCIAppInternalError,
             match="nb_participants not consistent with votes_by_participants",
         ):
-            AbstractRound.check_majority_possible({}, 0)
+            DummyConcreteRound(self.base_synchronized_data).check_majority_possible(
+                {}, 0
+            )
 
     def test_check_majority_possible_passes_when_vote_set_is_empty(self) -> None:
         """Check that 'check_majority_possible' passes when the set of votes is empty."""
-        AbstractRound.check_majority_possible({}, 1)
+        DummyConcreteRound(self.base_synchronized_data).check_majority_possible({}, 1)
 
     def test_check_majority_possible_passes_when_vote_set_nonempty_and_check_passes(
         self,
@@ -1224,7 +1240,9 @@ class TestAbstractRound:
         - the threshold is 2
         - the other voter can vote for the same item of the first voter
         """
-        AbstractRound.check_majority_possible({"alice": DummyPayload("alice", True)}, 2)
+        DummyConcreteRound(self.base_synchronized_data).check_majority_possible(
+            {"alice": DummyPayload("alice", True)}, 2
+        )
 
     def test_check_majority_possible_passes_when_payload_attributes_majority_match(
         self,
@@ -1236,7 +1254,7 @@ class TestAbstractRound:
         - the threshold is 3 (participants are 4)
         - 3 voters have the same attribute value in their payload
         """
-        AbstractRound.check_majority_possible(
+        DummyConcreteRound(self.base_synchronized_data).check_majority_possible(
             {
                 "voter_1": DummyPayload("voter_1", 0),
                 "voter_2": DummyPayload("voter_2", 0),
@@ -1259,7 +1277,7 @@ class TestAbstractRound:
             ABCIAppException,
             match="cannot reach quorum=2, number of remaining votes=0, number of most voted item's votes=1",
         ):
-            AbstractRound.check_majority_possible(
+            DummyConcreteRound(self.base_synchronized_data).check_majority_possible(
                 {
                     "alice": DummyPayload("alice", False),
                     "bob": DummyPayload("bob", True),
@@ -1269,13 +1287,13 @@ class TestAbstractRound:
 
     def test_is_majority_possible_positive_case(self) -> None:
         """Test 'is_majority_possible', positive case."""
-        assert AbstractRound.is_majority_possible(
+        assert DummyConcreteRound(self.base_synchronized_data).is_majority_possible(
             {"alice": DummyPayload("alice", False)}, 2
         )
 
     def test_is_majority_possible_negative_case(self) -> None:
         """Test 'is_majority_possible', negative case."""
-        assert not AbstractRound.is_majority_possible(
+        assert not DummyConcreteRound(self.base_synchronized_data).is_majority_possible(
             {
                 "alice": DummyPayload("alice", False),
                 "bob": DummyPayload("bob", True),
@@ -1288,7 +1306,9 @@ class TestAbstractRound:
     ) -> None:
         """Test 'check_majority_possible_with_new_vote' raises when new voter already voted."""
         with pytest.raises(ABCIAppInternalError, match="voter has already voted"):
-            AbstractRound.check_majority_possible_with_new_voter(
+            DummyConcreteRound(
+                self.base_synchronized_data
+            ).check_majority_possible_with_new_voter(
                 {"alice": DummyPayload("alice", False)},
                 "alice",
                 DummyPayload("alice", True),
@@ -1303,7 +1323,9 @@ class TestAbstractRound:
             ABCIAppInternalError,
             match="nb_participants not consistent with votes_by_participants",
         ):
-            AbstractRound.check_majority_possible_with_new_voter(
+            DummyConcreteRound(
+                self.base_synchronized_data
+            ).check_majority_possible_with_new_voter(
                 {"alice": DummyPayload("alice", True)},
                 "bob",
                 DummyPayload("bob", True),
@@ -1320,7 +1342,9 @@ class TestAbstractRound:
         - the number of participants is 2, and so the threshold is 2
         - the new voter votes for the same item already voted by voter 1.
         """
-        AbstractRound.check_majority_possible_with_new_voter(
+        DummyConcreteRound(
+            self.base_synchronized_data
+        ).check_majority_possible_with_new_voter(
             {"alice": DummyPayload("alice", True)}, "bob", DummyPayload("bob", True), 2
         )
 
@@ -1447,7 +1471,7 @@ class TestAbciApp:
 
     def setup(self) -> None:
         """Set up the test."""
-        self.abci_app = AbciAppTest(MagicMock(), MagicMock(), MagicMock())
+        self.abci_app = AbciAppTest(MagicMock(), MagicMock())
 
     @pytest.mark.parametrize("flag", (True, False))
     def test_is_abstract(self, flag: bool) -> None:
@@ -1459,13 +1483,6 @@ class TestAbciApp:
         CopyOfAbciApp._is_abstract = flag
         assert CopyOfAbciApp.is_abstract() is flag
 
-    @given(integers())
-    def test_reset_index(self, reset_index: int) -> None:
-        """Test `reset_index` getter and setter."""
-
-        self.abci_app.reset_index = reset_index
-        assert self.abci_app.reset_index == self.abci_app._reset_index == reset_index
-
     def test_initial_round_cls_not_set(self) -> None:
         """Test when 'initial_round_cls' is not set."""
 
@@ -1609,12 +1626,12 @@ class TestAbciApp:
         class EmptyAbciApp(AbciAppTest):
             """An AbciApp without termination attrs set."""
 
-            cross_period_persisted_keys = ["1", "2"]
+            cross_period_persisted_keys = {"1", "2"}
 
         class TerminationAbciApp(AbciAppTest):
             """A moch termination AbciApp."""
 
-            cross_period_persisted_keys = ["2", "3"]
+            cross_period_persisted_keys = {"2", "3"}
 
         EmptyAbciApp.add_termination(
             TerminationAbciApp.background_round_cls,
@@ -1625,7 +1642,7 @@ class TestAbciApp:
         assert EmptyAbciApp.background_round_cls is not None
         assert EmptyAbciApp.termination_transition_function is not None
         assert EmptyAbciApp.termination_event is not None
-        assert sorted(EmptyAbciApp.cross_period_persisted_keys) == ["1", "2", "3"]
+        assert EmptyAbciApp.cross_period_persisted_keys == {"1", "2", "3"}
 
     def test_background_round(self) -> None:
         """Test the background_round property."""
@@ -1650,8 +1667,7 @@ class TestAbciApp:
         dummy_synchronized_data = BaseSynchronizedData(
             db=AbciAppDB(setup_data=dict(participants=[max_participants]))
         )
-        dummy_consensus_params = ConsensusParams(max_participants)
-        dummy_round = ConcreteRoundA(dummy_synchronized_data, dummy_consensus_params)
+        dummy_round = ConcreteRoundA(dummy_synchronized_data)
 
         # Add dummy data
         self.abci_app._previous_rounds = [dummy_round] * start_history_depth
@@ -1734,7 +1750,7 @@ class TestRoundSequence:
     def setup(self) -> None:
         """Set up the test."""
         self.round_sequence = RoundSequence(abci_app_cls=AbciAppTest)
-        self.round_sequence.setup(MagicMock(), MagicMock(), MagicMock())
+        self.round_sequence.setup(MagicMock(), MagicMock())
         self.round_sequence.tm_height = 1
 
     @pytest.mark.parametrize("offset", tuple(range(5)))
@@ -1770,7 +1786,7 @@ class TestRoundSequence:
         seconds = 1
         nanoseconds = 1000
         expected_timestamp = datetime.datetime.fromtimestamp(
-            seconds + nanoseconds / 10 ** 9
+            seconds + nanoseconds / 10**9
         )
         self.round_sequence._blockchain.add_block(
             Block(MagicMock(height=1, timestamp=expected_timestamp), [])
@@ -1862,22 +1878,23 @@ class TestRoundSequence:
         assert expected in caplog.text
 
     @pytest.mark.parametrize("last_round_transition_root_hash", (b"", b"test"))
-    @pytest.mark.parametrize("round_count, reset_index", ((0, 0), (4, 2), (8, 1)))
     def test_last_round_transition_root_hash(
-        self, last_round_transition_root_hash: bytes, round_count: int, reset_index: int
+        self,
+        last_round_transition_root_hash: bytes,
     ) -> None:
         """Test 'last_round_transition_root_hash' method."""
         self.round_sequence._last_round_transition_root_hash = (
             last_round_transition_root_hash
         )
-        self.round_sequence.abci_app.synchronized_data.db.round_count = round_count
-        self.round_sequence.abci_app._reset_index = reset_index
 
         if last_round_transition_root_hash == b"":
-            assert (
-                self.round_sequence.last_round_transition_root_hash
-                == f"root:{round_count}reset:{reset_index}".encode("utf-8")
-            )
+            with mock.patch.object(
+                RoundSequence,
+                "root_hash",
+                new_callable=mock.PropertyMock,
+                return_value="test",
+            ):
+                assert self.round_sequence.last_round_transition_root_hash == "test"
         else:
             assert (
                 self.round_sequence.last_round_transition_root_hash
@@ -2208,10 +2225,17 @@ class TestRoundSequence:
                 result=background_round_result[0],
             )
 
+    @mock.patch.object(AbciAppDB, "sync")
     @pytest.mark.parametrize("restart_from_round", (ConcreteRoundA, MagicMock()))
-    def test_reset_state(self, restart_from_round: AbstractRound) -> None:
+    @pytest.mark.parametrize("serialized_db_state", (None, "serialized state"))
+    def test_reset_state(
+        self,
+        _: mock._patch,
+        restart_from_round: AbstractRound,
+        serialized_db_state: str,
+    ) -> None:
         """Tests reset_state"""
-        round_count, reset_index = 1, 1
+        round_count = 1
         with mock.patch.object(
             self.round_sequence,
             "_reset_to_default_params",
@@ -2219,7 +2243,9 @@ class TestRoundSequence:
             transition_fn = self.round_sequence.abci_app.transition_function
             round_id = restart_from_round.auto_round_id()
             if restart_from_round in transition_fn:
-                self.round_sequence.reset_state(round_id, round_count, reset_index)
+                self.round_sequence.reset_state(
+                    round_id, round_count, serialized_db_state
+                )
                 mock_reset.assert_called()
             else:
                 round_ids = {cls.auto_round_id() for cls in transition_fn}
@@ -2233,7 +2259,9 @@ class TestRoundSequence:
                     ),
                 ):
                     self.round_sequence.reset_state(
-                        restart_from_round.auto_round_id(), round_count, reset_index
+                        restart_from_round.auto_round_id(),
+                        round_count,
+                        serialized_db_state,
                     )
 
     def test_reset_to_default_params(self) -> None:
@@ -2271,22 +2299,12 @@ def test_meta_abci_app_when_instance_not_subclass_of_abstract_round() -> None:
 def test_meta_abci_app_when_final_round_not_subclass_of_degenerate_round() -> None:
     """Test instantiation of meta-class when a final round is not a subclass of DegenerateRound."""
 
-    class FinalRound(AbstractRound):
+    class FinalRound(AbstractRound, ABC):
         """A round class for testing."""
 
         payload_class = MagicMock()
         synchronized_data_class = MagicMock()
         payload_attribute = MagicMock()
-
-        def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
-            pass
-
-        def check_payload(self, payload: BaseTxPayload) -> None:
-            pass
-
-        def process_payload(self, payload: BaseTxPayload) -> None:
-            pass
-
         round_id = "final_round"
 
     with pytest.raises(
@@ -2328,7 +2346,7 @@ def test_synchronized_data_type_on_abci_app_init(caplog: LogCaptureFixture) -> N
 
     with mock.patch.object(AbciAppTest, "initial_round_cls") as m:
         m.synchronized_data_class = SynchronizedData
-        abci_app = AbciAppTest(synchronized_data, MagicMock(), logging.getLogger())
+        abci_app = AbciAppTest(synchronized_data, logging.getLogger())
         abci_app.setup()
         assert isinstance(abci_app.synchronized_data, SynchronizedData)
         assert abci_app.synchronized_data.dummy_attr == sentinel
