@@ -21,7 +21,7 @@
 
 # pylint: skip-file
 
-from enum import Enum
+from abc import ABC
 from pathlib import Path
 from typing import Any, Dict, Generator, Optional, Tuple
 from unittest import mock
@@ -153,14 +153,10 @@ class BehaviourB(BaseBehaviour):
         yield
 
 
-class BehaviourC(BaseBehaviour):
+class BehaviourC(BaseBehaviour, ABC):
     """Dummy behaviour."""
 
-    matching_round = RoundB
-
-    def async_act(self) -> Generator:
-        """Dummy act method."""
-        yield
+    matching_round = MagicMock()
 
 
 def test_auto_behaviour_id() -> None:
@@ -262,8 +258,6 @@ class TestAbstractRoundBehaviour:
                 behaviours = mock_behaviours  # type: ignore
                 initial_behaviour_cls = MagicMock()
 
-            MyRoundBehaviour(name=MagicMock(), skill_context=MagicMock())
-
     def test_get_behaviour_id_to_behaviour_mapping_negative(self) -> None:
         """Test classmethod '_get_behaviour_id_to_behaviour_mapping', negative case."""
         behaviour_id = "behaviour_id"
@@ -314,20 +308,9 @@ class TestAbstractRoundBehaviour:
     def test_get_round_to_behaviour_mapping_with_final_rounds(self) -> None:
         """Test classmethod '_get_round_to_behaviour_mapping' with final rounds."""
 
-        class FinalRound(DegenerateRound):
+        class FinalRound(DegenerateRound, ABC):
             """A final round for testing."""
 
-            synchronized_data_class = BaseSynchronizedData
-
-            def check_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def process_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
-                pass
-
         behaviour_id_1 = "behaviour_id_1"
         behaviour_1 = MagicMock(behaviour_id=behaviour_id_1, matching_round=RoundA)
 
@@ -623,7 +606,7 @@ def test_self_loops_in_abci_app_reinstantiate_behaviour(_: mock._patch) -> None:
 
     round_sequence = RoundSequence(AbciAppTest)
     round_sequence.end_sync()
-    round_sequence.setup(MagicMock(), MagicMock(), MagicMock())
+    round_sequence.setup(MagicMock(), MagicMock())
     context_mock = MagicMock()
     context_mock.state.round_sequence = round_sequence
     behaviour = RoundBehaviour(name="", skill_context=context_mock)
@@ -669,7 +652,7 @@ def test_reset_should_be_performed_when_tm_unhealthy() -> None:
 
     round_sequence = RoundSequence(AbciAppTest)
     round_sequence.end_sync()
-    round_sequence.setup(MagicMock(), MagicMock(), MagicMock())
+    round_sequence.setup(MagicMock(), MagicMock())
     context_mock = MagicMock()
     context_mock.state.round_sequence = round_sequence
     tm_recovery_params = TendermintRecoveryParams(
@@ -701,6 +684,7 @@ def test_reset_should_be_performed_when_tm_unhealthy() -> None:
         yield
 
     def dummy_reset_tendermint_with_wait(
+        on_startup: bool = False,
         is_recovery: bool = False,
     ) -> Generator[None, None, bool]:
         """A dummy method for reset_tendermint_with_wait."""
