@@ -21,26 +21,13 @@
 
 import json
 import logging
-import math
 import platform
 import time
 from abc import ABC
-from collections import OrderedDict
 from datetime import datetime
 from enum import Enum
 from pathlib import Path
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Generator,
-    List,
-    Optional,
-    Tuple,
-    Type,
-    Union,
-    cast,
-)
+from typing import Any, Callable, Dict, Generator, Optional, Tuple, Type, Union, cast
 from unittest import mock
 from unittest.mock import MagicMock
 
@@ -75,6 +62,7 @@ from packages.valory.skills.abstract_round_abci.base import (
     BaseSynchronizedData,
     BaseTxPayload,
     DegenerateRound,
+    OK_CODE,
     Transaction,
 )
 from packages.valory.skills.abstract_round_abci.behaviour_utils import (
@@ -83,12 +71,9 @@ from packages.valory.skills.abstract_round_abci.behaviour_utils import (
     BaseBehaviourInternalError,
     DegenerateBehaviour,
     GENESIS_TIME_FMT,
-    HEIGHT_OFFSET_MULTIPLIER,
+    INITIAL_HEIGHT,
     IPFSBehaviour,
-    MIN_HEIGHT_OFFSET,
     NON_200_RETURN_CODE_DURING_RESET_THRESHOLD,
-    RESET_HASH,
-    ROOT_HASH,
     RPCResponseStatus,
     SendException,
     TimeoutException,
@@ -178,12 +163,7 @@ class AsyncBehaviourTest(AsyncBehaviour, ABC):
 
     def async_act(self) -> Generator:
         """Do 'async_act'."""
-
-
-def async_behaviour_initial_state_is_ready() -> None:
-    """Check that the initial async state is "READY"."""
-    behaviour = AsyncBehaviourTest()
-    assert behaviour.state == AsyncBehaviour.AsyncState.READY
+        yield None
 
 
 def test_async_behaviour_ticks() -> None:
@@ -316,7 +296,6 @@ def test_async_behaviour_wait_for_condition_with_timeout() -> None:
         def async_act(self) -> Generator:
             self.counter += 1
             yield from self.wait_for_condition(lambda: False, timeout=0.05)
-            self.counter += 1
 
     behaviour = MyAsyncBehaviour()
     assert behaviour.counter == 0
@@ -383,10 +362,7 @@ def test_async_behaviour_without_yield() -> None:
 
     class MyAsyncBehaviour(AsyncBehaviourTest):
         def async_act_wrapper(self) -> Generator:
-            pass
-
-        def async_act(self) -> Generator:
-            pass
+            return None  # type: ignore  # need to check design, not sure it's proper case with return None
 
     behaviour = MyAsyncBehaviour()
     behaviour.act()
@@ -400,9 +376,6 @@ def test_async_behaviour_raise_stopiteration() -> None:
         def async_act_wrapper(self) -> Generator:
             raise StopIteration
 
-        def async_act(self) -> Generator:
-            pass
-
     behaviour = MyAsyncBehaviour()
     behaviour.act()
     assert behaviour.state == AsyncBehaviour.AsyncState.READY
@@ -435,7 +408,6 @@ class RoundA(AbstractRound):
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
         """Handle end block."""
-        return None
 
     def check_payload(self, payload: BaseTxPayload) -> None:
         """Check payload."""
@@ -451,26 +423,15 @@ class BehaviourATest(BaseBehaviour):
 
     def async_act(self) -> Generator:
         """Do the 'async_act'."""
-        yield
+        yield None
 
 
 def _get_status_patch_wrapper(
     latest_block_height: int,
-    expected_round_count: Optional[int],
-    expected_reset_index: Optional[int],
+    app_hash: str,
 ) -> Callable[[Any, Any], Generator[None, None, MagicMock]]:
     """Wrapper for `_get_status` method patch."""
 
-    if any(
-        app_hash_param is None
-        for app_hash_param in (expected_round_count, expected_reset_index)
-    ):
-        app_hash = ""
-    else:
-        app_hash = (
-            f"{ROOT_HASH}{expected_round_count}{RESET_HASH}{expected_reset_index}"
-        )
-
     def _get_status_patch(*_: Any, **__: Any) -> Generator[None, None, MagicMock]:
         """Patch `_get_status` method"""
         yield
@@ -822,36 +783,8 @@ class TestBaseBehaviour:
         gen = self.behaviour.send_a2a_transaction(MagicMock())
         try_send(gen)
 
-    def test_sync_state(self) -> None:
-        """Test `_sync_state`."""
-        app_hash = ""
-        self.behaviour._sync_state(app_hash)
-        assert self.behaviour.context.state.round_sequence.abci_app.reset_index == 0
-
-        app_hash = "726F6F743A356072657365743A370"
-        self.behaviour._sync_state(app_hash)
-        assert self.behaviour.context.state.round_sequence.abci_app.reset_index == 70
-
-        app_hash = "incorrect"
-        with pytest.raises(
-            ValueError,
-            match=(
-                "Expected an app hash of the form: `726F6F743A3{ROUND_COUNT}72657365743A3{RESET_INDEX}`,"
-                "which is derived from `root:{ROUND_COUNT}reset:{RESET_INDEX}`. "
-                "For example, `root:90reset:4` would be `726F6F743A39072657365743A34`. "
-                f"However, the app hash received is: `{app_hash}`."
-            ),
-        ):
-            self.behaviour._sync_state(app_hash)
-
-    @pytest.mark.parametrize(
-        "expected_round_count, expected_reset_index",
-        ((None, None), (0, 0), (123, 4), (235235, 754)),
-    )
     def test_async_act_wrapper_agent_sync_mode(
         self,
-        expected_round_count: Optional[int],
-        expected_reset_index: Optional[int],
     ) -> None:
         """Test 'async_act_wrapper' in sync mode."""
         self.behaviour.context.state.round_sequence.syncing_up = True
@@ -861,24 +794,13 @@ class TestBaseBehaviour:
         with mock.patch.object(logging, "info") as log_mock, mock.patch.object(
             BaseBehaviour,
             "_get_status",
-            _get_status_patch_wrapper(0, expected_round_count, expected_reset_index),
+            _get_status_patch_wrapper(0, "test"),
         ):
             gen = self.behaviour.async_act_wrapper()
             for __ in range(3):
                 try_send(gen)
             log_mock.assert_called_with("local height == remote == 0; Sync complete...")
 
-        if any(
-            app_hash_param is None
-            for app_hash_param in (expected_round_count, expected_reset_index)
-        ):
-            expected_reset_index = 0
-
-        assert (
-            self.behaviour.context.state.round_sequence.abci_app.reset_index
-            == expected_reset_index
-        )
-
     @mock.patch.object(BaseBehaviour, "_get_status", _get_status_wrong_patch)
     def test_async_act_wrapper_agent_sync_mode_where_height_dont_match(self) -> None:
         """Test 'async_act_wrapper' in sync mode."""
@@ -1199,7 +1121,6 @@ class TestBaseBehaviour:
                 "Received tendermint code != 0. Retrying in 1.0 seconds..."
             )
 
-    @pytest.mark.skip
     @mock.patch.object(BaseBehaviour, "_send_signing_request")
     @mock.patch.object(Transaction, "encode", return_value=MagicMock())
     @mock.patch.object(
@@ -1212,7 +1133,7 @@ class TestBaseBehaviour:
         "_check_http_return_code_200",
         return_value=True,
     )
-    @mock.patch("json.loads")
+    @mock.patch("json.loads", return_value={"result": {"hash": "", "code": OK_CODE}})
     def test_send_transaction_wait_delivery_timeout_exception(self, *_: Any) -> None:
         """Test '_send_transaction', timeout exception on tx delivery."""
         timeout = 0.05
@@ -1354,8 +1275,8 @@ class TestBaseBehaviour:
             self.behaviour._build_http_request_message(
                 "",
                 "",
-                parameters=[("foo", "bar")],
-                headers=[OrderedDict({"foo": "foo_val", "bar": "bar_val"})],
+                parameters={"foo": "bar"},
+                headers={"foo": "foo_val", "bar": "bar_val"},
             )
 
     @mock.patch.object(Transaction, "encode", return_value=MagicMock())
@@ -2002,9 +1923,15 @@ class TestBaseBehaviour:
         ),
         st.integers(),
         st.integers(),
+        st.integers(),
     )
     def test_get_reset_params(
-        self, default: bool, timestamp: datetime, height: int, interval: int
+        self,
+        default: bool,
+        timestamp: datetime,
+        height: int,
+        interval: int,
+        period: int,
     ) -> None:
         """Test `_get_reset_params` method."""
         self.context_mock.state.round_sequence.last_round_transition_timestamp = (
@@ -2012,6 +1939,7 @@ class TestBaseBehaviour:
         )
         self.context_mock.state.round_sequence.last_round_transition_tm_height = height
         self.behaviour.params.observation_interval = interval
+        self.context_state_synchronized_data_mock.period_count = period
 
         actual = self.behaviour._get_reset_params(default)
 
@@ -2019,15 +1947,15 @@ class TestBaseBehaviour:
             assert actual is None
 
         else:
-            offset = math.ceil(interval * HEIGHT_OFFSET_MULTIPLIER)
-            offset = max(MIN_HEIGHT_OFFSET, offset)
-            initial_height = str(height + offset)
+            initial_height = INITIAL_HEIGHT
             genesis_time = timestamp.astimezone(pytz.UTC).strftime(GENESIS_TIME_FMT)
+            period_count = str(period)
 
-            expected = [
-                ("genesis_time", genesis_time),
-                ("initial_height", initial_height),
-            ]
+            expected = {
+                "genesis_time": genesis_time,
+                "initial_height": initial_height,
+                "period_count": period_count,
+            }
 
             assert actual == expected
 
@@ -2127,6 +2055,8 @@ class TestBaseBehaviour:
                 return mock.MagicMock(body=b"")
             return mock.MagicMock(body=json.dumps(status_response).encode())
 
+        period_count_mock = MagicMock()
+        self.context_state_synchronized_data_mock.period_count = period_count_mock
         self.behaviour.params.observation_interval = 1
         with mock.patch.object(
             BaseBehaviour, "_is_timeout_expired", return_value=False
@@ -2145,15 +2075,7 @@ class TestBaseBehaviour:
             reset = self.behaviour.reset_tendermint_with_wait(on_startup=on_startup)
             for _ in range(n_iter):
                 next(reset)
-            offset = math.ceil(
-                self.behaviour.params.observation_interval * HEIGHT_OFFSET_MULTIPLIER
-            )
-            offset = max(MIN_HEIGHT_OFFSET, offset)
-            assert offset == 10
-            initial_height = str(
-                self.behaviour.context.state.round_sequence.last_round_transition_tm_height
-                + offset
-            )
+            initial_height = INITIAL_HEIGHT
             genesis_time = self.behaviour.context.state.round_sequence.last_round_transition_timestamp.astimezone(
                 pytz.UTC
             ).strftime(
@@ -2161,10 +2083,11 @@ class TestBaseBehaviour:
             )
 
             expected_parameters = (
-                [
-                    ("genesis_time", genesis_time),
-                    ("initial_height", initial_height),
-                ]
+                {
+                    "genesis_time": genesis_time,
+                    "initial_height": initial_height,
+                    "period_count": str(period_count_mock),
+                }
                 if not on_startup
                 else None
             )
@@ -2191,10 +2114,6 @@ class TestBaseBehaviour:
                         tm_recovery_params.round_count
                         == shared_state.synchronized_data.db.round_count - 1
                     )
-                    assert (
-                        tm_recovery_params.reset_index
-                        == shared_state.round_sequence.abci_app.reset_index - 1
-                    )
                     assert (
                         tm_recovery_params.reset_from_round
                         == self.behaviour.matching_round.auto_round_id()
@@ -2241,20 +2160,9 @@ def test_degenerate_behaviour_async_act() -> None:
 def test_make_degenerate_behaviour() -> None:
     """Test 'make_degenerate_behaviour'."""
 
-    class FinalRound(DegenerateRound):
+    class FinalRound(DegenerateRound, ABC):
         """A final round for testing."""
 
-        synchronized_data_class = BaseSynchronizedData
-
-        def check_payload(self, payload: BaseTxPayload) -> None:
-            pass
-
-        def process_payload(self, payload: BaseTxPayload) -> None:
-            pass
-
-        def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
-            pass
-
     new_cls = make_degenerate_behaviour(FinalRound)
 
     assert isinstance(new_cls, type)
@@ -2284,7 +2192,9 @@ class TestTmManager:
                 consensus_threshold=self._DUMMY_CONSENSUS_THRESHOLD
             ),
         )
-        self.context_state_synchronized_data_mock = MagicMock()
+        self.context_state_synchronized_data_mock = MagicMock(
+            consensus_threshold=self._DUMMY_CONSENSUS_THRESHOLD
+        )
         self.context_mock.params = self.context_params_mock
         self.context_mock.state.synchronized_data = (
             self.context_state_synchronized_data_mock
@@ -2374,15 +2284,12 @@ class TestTmManager:
     @pytest.mark.parametrize(
         "expected_reset_params",
         (
-            [
-                ("genesis_time", "genesis-time"),
-                ("initial_height", "1"),
-            ],
+            {"genesis_time": "genesis-time", "initial_height": "1"},
             None,
         ),
     )
     def test_get_reset_params(
-        self, expected_reset_params: Optional[List[Tuple[str, str]]]
+        self, expected_reset_params: Optional[Dict[str, str]]
     ) -> None:
         """Test that reset params returns the correct params."""
         self.context_mock.state.tm_recovery_params = TendermintRecoveryParams(
