@@ -323,22 +323,12 @@ class TestTendermintHandler:
         """Set up the tests."""
         self.agent_name = "Alice"
         self.context = MagicMock(skill_id=PublicId.from_str("dummy/skill:0.1.0"))
+        other_agents = ["Alice", "Bob", "Charlie"]
+        self.context.state = MagicMock(acn_container=lambda: other_agents)
         self.handler = TendermintHandler(name="dummy", skill_context=self.context)
         self.handler.context.logger = logging.getLogger()
         self.dialogues = TendermintDialogues(name="dummy", skill_context=self.context)
 
-    # helper
-    def mocked_registered_addresses(
-        self, addresses: Dict[str, Dict[str, str]]
-    ) -> mock._patch:
-        """Mocked registered addresses"""
-        return mock.patch.object(
-            TendermintHandler,
-            "registered_addresses",
-            new_callable=mock.PropertyMock,
-            return_value=addresses,
-        )
-
     @property
     def dummy_validator_config(self) -> Dict[str, Dict[str, str]]:
         """Dummy validator config"""
@@ -351,7 +341,8 @@ class TestTendermintHandler:
             }
         }
 
-    def make_error_message(self) -> TendermintMessage:
+    @staticmethod
+    def make_error_message() -> TendermintMessage:
         """Make dummy error message"""
         performative = TendermintMessage.Performative.ERROR
         error_code = TendermintMessage.ErrorCode.INVALID_REQUEST
@@ -381,12 +372,12 @@ class TestTendermintHandler:
         performative = TendermintMessage.Performative.GET_GENESIS_INFO
         message = TendermintMessage(performative)  # type: ignore
         message.sender = "Alice"
-        with self.mocked_registered_addresses({}):
-            self.handler.handle(message)
-            log_message = self.handler.LogMessages.no_addresses_retrieved_yet.value
-            assert log_message in caplog.text
-            log_message = self.handler.LogMessages.sending_error_response.value
-            assert log_message in caplog.text
+        self.handler.initial_tm_configs = {}
+        self.handler.handle(message)
+        log_message = self.handler.LogMessages.no_addresses_retrieved_yet.value
+        assert log_message in caplog.text
+        log_message = self.handler.LogMessages.sending_error_response.value
+        assert log_message in caplog.text
 
     def test_handle_not_in_registered_addresses(
         self, caplog: LogCaptureFixture
@@ -394,7 +385,7 @@ class TestTendermintHandler:
         """Test handle response sender not in registered addresses"""
         performative = TendermintMessage.Performative.GENESIS_INFO
         message = TendermintMessage(performative, info="info")  # type: ignore
-        message.sender = "Alice"
+        message.sender = "NotAlice"
         self.handler.handle(message)
         log_message = self.handler.LogMessages.not_in_registered_addresses.value
         assert log_message in caplog.text
@@ -405,10 +396,10 @@ class TestTendermintHandler:
         performative = TendermintMessage.Performative.GET_GENESIS_INFO
         message = TendermintMessage(performative)  # type: ignore
         self.context.agent_address = message.sender = self.agent_name
-        with self.mocked_registered_addresses(self.dummy_validator_config):
-            self.handler.handle(message)
-            log_message = self.handler.LogMessages.sending_request_response.value
-            assert log_message in caplog.text
+        self.handler.initial_tm_configs = self.dummy_validator_config
+        self.handler.handle(message)
+        log_message = self.handler.LogMessages.sending_request_response.value
+        assert log_message in caplog.text
 
     # response
     def test_handle_response_invalid_addresses(self, caplog: LogCaptureFixture) -> None:
@@ -419,8 +410,8 @@ class TestTendermintHandler:
         info = json.dumps(validator_config[self.agent_name])
         message = TendermintMessage(performative, info=info)  # type: ignore
         self.context.agent_address = message.sender = self.agent_name
-        with self.mocked_registered_addresses(validator_config):
-            self.handler.handle(message)
+        self.handler.initial_tm_configs = validator_config
+        self.handler.handle(message)
         log_message = self.handler.LogMessages.failed_to_parse_address.value
         assert log_message in caplog.text
 
@@ -430,8 +421,8 @@ class TestTendermintHandler:
         info = json.dumps(self.dummy_validator_config[self.agent_name])
         message = TendermintMessage(performative, info=info)  # type: ignore
         self.context.agent_address = message.sender = self.agent_name
-        with self.mocked_registered_addresses(self.dummy_validator_config):
-            self.handler.handle(message)
+        self.handler.initial_tm_configs = self.dummy_validator_config
+        self.handler.handle(message)
         log_message = self.handler.LogMessages.collected_config_info.value
         assert log_message in caplog.text
 
@@ -450,6 +441,9 @@ class TestTendermintHandler:
         caplog: LogCaptureFixture,
     ) -> None:
         """Test handle response for recovery parameters."""
+        if not registered:
+            self.agent_name = "not-registered"
+
         if performative == TendermintMessage.Performative.GET_RECOVERY_PARAMS:
             self.context.state.tm_recovery_params = TendermintRecoveryParams(
                 "DummyRound"
@@ -468,12 +462,10 @@ class TestTendermintHandler:
             )
 
         self.context.agent_address = message.sender = self.agent_name
-        registered_addresses = (
-            {self.agent_name: {"dummy": "value"}} if registered else {}
-        )
+        tm_configs = {self.agent_name: {"dummy": "value"}} if registered else {}
 
-        with self.mocked_registered_addresses(registered_addresses):
-            self.handler.handle(message)
+        self.handler.initial_tm_configs = tm_configs
+        self.handler.handle(message)
 
         if not registered:
             log_message = self.handler.LogMessages.not_in_registered_addresses.value
@@ -505,10 +497,9 @@ class TestTendermintHandler:
         )
 
         self.context.agent_address = message.sender = self.agent_name
-        registered_addresses = {self.agent_name: {"dummy": "value"}}
-        with self.mocked_registered_addresses(registered_addresses), mock.patch.object(
-            json, "loads", side_effect=side_effect
-        ):
+        tm_configs = {self.agent_name: {"dummy": "value"}}
+        self.handler.initial_tm_configs = tm_configs
+        with mock.patch.object(json, "loads", side_effect=side_effect):
             self.handler.handle(message)
 
         log_message = self.handler.LogMessages.failed_to_parse_params.value
@@ -519,8 +510,8 @@ class TestTendermintHandler:
     def test_handle_error(self, caplog: LogCaptureFixture) -> None:
         """Test handle error"""
         message = self.make_error_message()
-        with self.mocked_registered_addresses(self.dummy_validator_config):
-            self.handler.handle(message)
+        self.handler.initial_tm_configs = self.dummy_validator_config
+        self.handler.handle(message)
         log_message = self.handler.LogMessages.received_error_response.value
         assert log_message in caplog.text
 
@@ -534,8 +525,8 @@ class TestTendermintHandler:
         self.handler.dialogues.update = lambda _: dialogue  # type: ignore
         callback = lambda *args, **kwargs: None  # noqa: E731
         self.context.requests.request_id_to_callback = {nonce: callback}
-        with self.mocked_registered_addresses(self.dummy_validator_config):
-            self.handler.handle(message)
+        self.handler.initial_tm_configs = self.dummy_validator_config
+        self.handler.handle(message)
         log_message = (
             self.handler.LogMessages.received_error_without_target_message.value
         )
@@ -548,8 +539,8 @@ class TestTendermintHandler:
         """Test performative no recognized"""
         message = self.make_error_message()
         message._slots.performative = MagicMock(value="wacky")
-        with self.mocked_registered_addresses(self.dummy_validator_config):
-            self.handler.handle(message)
+        self.handler.initial_tm_configs = self.dummy_validator_config
+        self.handler.handle(message)
         log_message = self.handler.LogMessages.performative_not_recognized.value
         assert log_message in caplog.text
 
@@ -561,7 +552,7 @@ class TestTendermintHandler:
         performative = TendermintMessage.Performative.GET_GENESIS_INFO
         message = TendermintMessage(performative)  # type: ignore
         self.context.agent_address = message.sender = "dummy"
-        with self.mocked_registered_addresses(self.dummy_validator_config):
-            self.handler.handle(message)
-            log_message = self.handler.LogMessages.not_in_registered_addresses.value
-            assert log_message in caplog.text
+        self.handler.initial_tm_configs = self.dummy_validator_config
+        self.handler.handle(message)
+        log_message = self.handler.LogMessages.not_in_registered_addresses.value
+        assert log_message in caplog.text
