@@ -24,6 +24,7 @@
 import builtins
 import json
 import logging
+from collections import OrderedDict
 from dataclasses import dataclass
 from enum import Enum
 from pathlib import Path
@@ -40,7 +41,6 @@ from typing_extensions import Literal, TypedDict
 from packages.valory.skills.abstract_round_abci.base import (
     AbstractRound,
     BaseSynchronizedData,
-    RESET_INDEX_DEFAULT,
     ROUND_COUNT_DEFAULT,
 )
 from packages.valory.skills.abstract_round_abci.models import (
@@ -53,6 +53,7 @@ from packages.valory.skills.abstract_round_abci.models import (
     GenesisConsensusParams,
     GenesisEvidence,
     GenesisValidator,
+    MIN_OBSERVATION_INTERVAL,
     NUMBER_OF_RETRIES,
     Requests,
 )
@@ -76,8 +77,39 @@ BASE_DUMMY_SPECS_CONFIG = dict(
     url="http://dummy",
     api_id="api_id",
     method="GET",
-    headers=[("Dummy-Header", "dummy_value")],
-    parameters=[("Dummy-Param", "dummy_param")],
+    headers=OrderedDict([("Dummy-Header", "dummy_value")]),
+    parameters=OrderedDict([("Dummy-Param", "dummy_param")]),
+)
+
+BASE_DUMMY_PARAMS = dict(
+    name="",
+    skill_context=MagicMock(is_abstract_component=True),
+    setup={},
+    tendermint_url="",
+    max_healthcheck=1,
+    round_timeout_seconds=1.0,
+    sleep_time=1,
+    retry_timeout=1,
+    retry_attempts=1,
+    observation_interval=MIN_OBSERVATION_INTERVAL,
+    drand_public_key="",
+    tendermint_com_url="",
+    reset_tendermint_after=1,
+    service_id="abstract_round_abci",
+    service_registry_address="0xa51c1fc2f0d1a1b8494ed1fe312d7c3a78ed91c0",
+    keeper_timeout=1.0,
+    tendermint_check_sleep_delay=3,
+    tendermint_max_retries=5,
+    cleanup_history_depth=0,
+    genesis_config=irrelevant_genesis_config,
+    cleanup_history_depth_current=None,
+    request_timeout=0.0,
+    request_retry_delay=0.0,
+    tx_timeout=0.0,
+    max_attempts=0,
+    on_chain_service_id=None,
+    share_tm_config_on_startup=False,
+    tendermint_p2p_url="",
 )
 
 
@@ -124,8 +156,8 @@ class TestApiSpecsModel:
         assert self.api_specs.url == "http://dummy"
         assert self.api_specs.api_id == "api_id"
         assert self.api_specs.method == "GET"
-        assert self.api_specs.headers == [("Dummy-Header", "dummy_value")]
-        assert self.api_specs.parameters == [("Dummy-Param", "dummy_param")]
+        assert self.api_specs.headers == {"Dummy-Header": "dummy_value"}
+        assert self.api_specs.parameters == {"Dummy-Param": "dummy_param"}
         assert self.api_specs.response_info.response_key == "value"
         assert self.api_specs.response_info.response_index == 0
         assert self.api_specs.response_info.response_type == "float"
@@ -140,7 +172,7 @@ class TestApiSpecsModel:
         self.api_specs.retries_info.retries_attempted = retries
         assert (
             self.api_specs.retries_info.suggested_sleep_time
-            == DEFAULT_BACKOFF_FACTOR ** retries
+            == DEFAULT_BACKOFF_FACTOR**retries
         )
 
     def test_retries(
@@ -166,8 +198,8 @@ class TestApiSpecsModel:
         actual_specs = {
             "url": "http://dummy",
             "method": "GET",
-            "headers": [("Dummy-Header", "dummy_value")],
-            "parameters": [("Dummy-Param", "dummy_param")],
+            "headers": {"Dummy-Header": "dummy_value"},
+            "parameters": {"Dummy-Param": "dummy_param"},
         }
 
         specs = self.api_specs.get_spec()
@@ -343,25 +375,48 @@ class TestSharedState:
         """Test the initialization of the shared state."""
         SharedState(name="", skill_context=MagicMock())
 
+    @staticmethod
+    def dummy_state_setup(shared_state: SharedState) -> None:
+        """Setup a shared state instance with dummy params."""
+        shared_state.context.params.setup_params = {
+            "test": [],
+            "all_participants": [list(range(4))],
+        }
+        shared_state.setup()
+
     def test_setup(self, *_: Any) -> None:
         """Test setup method."""
-        shared_state = SharedState(name="", skill_context=MagicMock())
-        shared_state.context.params.setup_params = {"test": []}
-        shared_state.context.params.consensus_params = MagicMock()
-        shared_state.setup()
+        shared_state = SharedState(
+            name="", skill_context=MagicMock(is_abstract_component=False)
+        )
+        assert shared_state.initial_tm_configs == {}
+        self.dummy_state_setup(shared_state)
+        assert shared_state.initial_tm_configs == {i: None for i in range(4)}
+
+    @pytest.mark.parametrize("self_idx", (range(4)))
+    def test_acn_container(self, self_idx: int) -> None:
+        """Test the `acn_container` method."""
+
+        shared_state = SharedState(
+            name="", skill_context=MagicMock(agent_address=self_idx)
+        )
+        self.dummy_state_setup(shared_state)
+        expected = {i: None for i in range(4) if i != self_idx}
+        assert shared_state.acn_container() == expected
 
     def test_synchronized_data_negative_not_available(self, *_: Any) -> None:
         """Test 'synchronized_data' property getter, negative case (not available)."""
         shared_state = SharedState(name="", skill_context=MagicMock())
-        with mock.patch.object(shared_state.context, "params"):
-            with pytest.raises(ValueError, match="round sequence not available"):
-                shared_state.synchronized_data
+        with pytest.raises(ValueError, match="round sequence not available"):
+            shared_state.synchronized_data
 
     def test_synchronized_data_positive(self, *_: Any) -> None:
         """Test 'synchronized_data' property getter, negative case (not available)."""
         shared_state = SharedState(name="", skill_context=MagicMock())
-        shared_state.context.params.setup_params = {"test": []}
-        shared_state.context.params.consensus_params = MagicMock()
+        shared_state.context.params.setup_params = {
+            "test": [],
+            "all_participants": [["0x0"]],
+        }
         shared_state.setup()
         shared_state.round_sequence.abci_app._round_results = [MagicMock()]
         shared_state.synchronized_data
@@ -373,6 +428,7 @@ class TestSharedState:
             mock_params.setup_params = {
                 "safe_contract_address": ["0xsafe"],
                 "oracle_contract_address": ["0xoracle"],
+                "all_participants": ["0x0"],
             }
             shared_state.setup()
             assert (
@@ -409,9 +465,12 @@ class TestSharedState:
         shared_state = SharedState(
             abci_app_cls=AbciAppTest, name="", skill_context=MagicMock()
         )
-        shared_state.context.params.setup_params = {"test": []}
+        shared_state.context.params.setup_params = {
+            "test": [],
+            "all_participants": [["0x0"]],
+        }
         shared_state.setup()
-        shared_state.synchronized_data.update(participants=set(range(n_participants)))
+        shared_state.synchronized_data.update(participants=tuple(range(n_participants)))
         shared_state.address_to_acn_deliverable = address_to_acn_deliverable
         actual = shared_state.get_acn_result()
 
@@ -422,7 +481,6 @@ class TestSharedState:
         shared_state = SharedState(name="", skill_context=MagicMock())
         assert shared_state.tm_recovery_params is not None
         assert shared_state.tm_recovery_params.round_count == ROUND_COUNT_DEFAULT
-        assert shared_state.tm_recovery_params.reset_index == RESET_INDEX_DEFAULT
         assert (
             shared_state.tm_recovery_params.reset_from_round
             == AbciAppTest.initial_round_cls.auto_round_id()
@@ -489,37 +547,7 @@ def test_requests_model_initialization() -> None:
 
 def test_base_params_model_initialization() -> None:
     """Test initialization of the 'BaseParams(Model)' class."""
-    kwargs = dict(
-        name="",
-        skill_context=MagicMock(),
-        setup={},
-        consensus=dict(max_participants=1),
-        tendermint_url="",
-        max_healthcheck=1,
-        round_timeout_seconds=1.0,
-        sleep_time=1,
-        retry_timeout=1,
-        retry_attempts=1,
-        observation_interval=1,
-        drand_public_key="",
-        tendermint_com_url="",
-        reset_tendermint_after=1,
-        service_id="abstract_round_abci",
-        service_registry_address="0xa51c1fc2f0d1a1b8494ed1fe312d7c3a78ed91c0",
-        keeper_timeout=1.0,
-        tendermint_check_sleep_delay=3,
-        tendermint_max_retries=5,
-        cleanup_history_depth=0,
-        genesis_config=irrelevant_genesis_config,
-        cleanup_history_depth_current=None,
-        request_timeout=0.0,
-        request_retry_delay=0.0,
-        tx_timeout=0.0,
-        max_attempts=0,
-        on_chain_service_id=None,
-        share_tm_config_on_startup=False,
-        tendermint_p2p_url="",
-    )
+    kwargs = BASE_DUMMY_PARAMS.copy()
     bp = BaseParams(**kwargs)
 
     with pytest.raises(AttributeError, match="This object is frozen!"):
@@ -533,11 +561,43 @@ def test_base_params_model_initialization() -> None:
 
     assert getattr(bp, "request_timeout", None) is None
 
+    kwargs["skill_context"] = MagicMock(is_abstract_component=False)
+    required_setup_params = {
+        "safe_contract_address",
+        "all_participants",
+        "consensus_threshold",
+    }
+    kwargs["setup"] = {setup_param: [] for setup_param in required_setup_params}
+    BaseParams(**kwargs)
+
+
+@pytest.mark.parametrize(
+    "setup, error_text",
+    (
+        ({}, "`setup` params contain no values!"),
+        (
+            {"a": "b"},
+            "Value for `safe_contract_address` missing from the `setup` params.",
+        ),
+    ),
+)
+def test_incorrect_setup(setup: Dict[str, Any], error_text: str) -> None:
+    """Test BaseParams model initialization with incorrect setup data."""
+    kwargs = BASE_DUMMY_PARAMS.copy()
+
     with pytest.raises(
-        TypeError,
-        match="Value `b` in `setup` set in `models.params.args` of `skill.yaml` of .* is not a list",
+        AEAEnforceError,
+        match=error_text,
     ):
-        kwargs["setup"] = {"a": "b"}
+        kwargs["skill_context"] = MagicMock(is_abstract_component=False)
+        kwargs["setup"] = setup
+        BaseParams(**kwargs)
+
+    with pytest.raises(
+        AEAEnforceError,
+        match=f"`observation_interval` must be greater than or equal to {MIN_OBSERVATION_INTERVAL}",
+    ):
+        kwargs["observation_interval"] = MIN_OBSERVATION_INTERVAL - 1
         BaseParams(**kwargs)
 
 
