@@ -24,7 +24,11 @@
 import logging  # noqa: F401
 from typing import cast
 
-from packages.valory.skills.abstract_round_abci.base import AbciAppDB, MAX_INT_256
+from packages.valory.skills.abstract_round_abci.base import (
+    AbciAppDB,
+    CollectionRound,
+    MAX_INT_256,
+)
 from packages.valory.skills.abstract_round_abci.test_tools.rounds import (
     BaseRoundTestClass as ExternalBaseRoundTestClass,
 )
@@ -67,7 +71,6 @@ class TestRegistrationRound(BaseRoundTestClass):
 
         test_round = RegistrationRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         first_payload, *payloads = [
@@ -82,7 +85,7 @@ class TestRegistrationRound(BaseRoundTestClass):
             test_round.process_payload(payload)
 
         actual_next_behaviour = SynchronizedData(
-            AbciAppDB(setup_data=dict(participants=[frozenset(test_round.collection)]))
+            AbciAppDB(setup_data=dict(participants=[tuple(test_round.collection)]))
         )
 
         res = test_round.end_block()
@@ -105,7 +108,6 @@ class TestCollectRandomnessRound(BaseRoundTestClass):
 
         test_round = CollectRandomnessRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
         first_payload, *payloads = [
             CollectRandomnessPayload(
@@ -124,7 +126,7 @@ class TestCollectRandomnessRound(BaseRoundTestClass):
             test_round.process_payload(payload)
 
         actual_next_behaviour = self.synchronized_data.update(
-            participant_to_randomness=test_round.collection,
+            participant_to_randomness=test_round.serialized_collection,
             most_voted_randomness=test_round.most_voted_payload,
         )
 
@@ -153,7 +155,6 @@ class TestSelectKeeperRound(BaseRoundTestClass):
 
         test_round = SelectKeeperRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         first_payload, *payloads = [
@@ -171,7 +172,7 @@ class TestSelectKeeperRound(BaseRoundTestClass):
             test_round.process_payload(payload)
 
         actual_next_behaviour = self.synchronized_data.update(
-            participant_to_selection=test_round.collection,
+            participant_to_selection=test_round.serialized_collection,
             most_voted_keeper_address=test_round.most_voted_payload,
         )
 
@@ -200,7 +201,6 @@ class TestPrintMessageRound(BaseRoundTestClass):
 
         test_round = PrintMessageRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         first_payload, *payloads = [
@@ -223,8 +223,8 @@ class TestPrintMessageRound(BaseRoundTestClass):
         actual_next_behaviour = SynchronizedData(
             AbciAppDB(
                 setup_data=dict(
-                    participants=[test_round.collection],
-                    printed_messages=[printed_messages],
+                    participants=[tuple(sorted(test_round.collection))],
+                    printed_messages=[sorted(printed_messages)],
                 )
             )
         )
@@ -253,7 +253,6 @@ class TestResetAndPauseRound(BaseRoundTestClass):
         """Run tests."""
         test_round = ResetAndPauseRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         first_payload, *payloads = [
@@ -271,8 +270,9 @@ class TestResetAndPauseRound(BaseRoundTestClass):
             test_round.process_payload(payload)
 
         actual_next_behaviour = self.synchronized_data.create(
-            participants=[self.synchronized_data.participants],
-            all_participants=[self.synchronized_data.all_participants],
+            participants=[tuple(self.synchronized_data.participants)],
+            all_participants=[tuple(self.synchronized_data.all_participants)],
+            consensus_threshold=[3],
         )
 
         res = test_round.end_block()
@@ -290,18 +290,24 @@ class TestResetAndPauseRound(BaseRoundTestClass):
 def test_synchronized_data() -> None:  # pylint:too-many-locals
     """Test SynchronizedData."""
 
-    participants = frozenset([f"agent_{i}" for i in range(MAX_PARTICIPANTS)])
+    participants = tuple(f"agent_{i}" for i in range(MAX_PARTICIPANTS))
     participant_to_randomness = {
         participant: CollectRandomnessPayload(
             sender=participant, randomness=RANDOMNESS, round_id=0
         )
         for participant in participants
     }
+    participant_to_randomness_serialized = CollectionRound.serialize_collection(
+        participant_to_randomness
+    )
     most_voted_randomness = "0xabcd"
     participant_to_selection = {
         participant: SelectKeeperPayload(sender=participant, keeper="keeper")
         for participant in participants
     }
+    participant_to_selection_serialized = CollectionRound.serialize_collection(
+        participant_to_selection
+    )
     most_voted_keeper_address = "keeper"
 
     synchronized_data = SynchronizedData(
@@ -310,16 +316,16 @@ def test_synchronized_data() -> None:  # pylint:too-many-locals
                 dict(
                     participants=participants,
                     setup_params={},
-                    participant_to_randomness=participant_to_randomness,
+                    participant_to_randomness=participant_to_randomness_serialized,
                     most_voted_randomness=most_voted_randomness,
-                    participant_to_selection=participant_to_selection,
+                    participant_to_selection=participant_to_selection_serialized,
                     most_voted_keeper_address=most_voted_keeper_address,
                 )
             ),
         )
     )
 
-    assert synchronized_data.participants == participants
+    assert synchronized_data.participants == frozenset(participants)
     assert synchronized_data.period_count == 0
     assert synchronized_data.participant_to_randomness == participant_to_randomness
     assert synchronized_data.most_voted_randomness == most_voted_randomness
