@@ -68,6 +68,7 @@ PACKAGE_DIR = Path(__file__).parent.parent
 
 
 SERVICE_REGISTRY_ADDRESS = "0xa51c1fc2f0d1a1b8494ed1fe312d7c3a78ed91c0"
+ZERO_ADDRESS = "0x0000000000000000000000000000000000000000"
 CONTRACT_ID = str(ServiceRegistryContract.contract_id)
 ON_CHAIN_SERVICE_ID = 42
 DUMMY_ADDRESS = "localhost"
@@ -118,9 +119,9 @@ class BaseRegistrationTestBehaviour(RegistrationAbciBaseCase):
     @pytest.mark.parametrize(
         "setup_data, expected_initialisation",
         (
-            ({}, "{}"),
-            ({"test": []}, "{}"),
-            ({"test": [], "valid": [1, 2]}, '{"valid": [1, 2]}'),
+            ({}, '{"0": {}}'),
+            ({"test": []}, '{"0": {}}'),
+            ({"test": [], "valid": [1, 2]}, '{"0": {"valid": [1, 2]}}'),
         ),
     )
     def test_registration(
@@ -178,6 +179,11 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
         self.state.params.__dict__["sleep_time"] = 0.01
         self.state.params.__dict__["share_tm_config_on_startup"] = True
 
+    def teardown(self, **kwargs: Any) -> None:
+        """Teardown."""
+        super().teardown(**kwargs)
+        self.state.initial_tm_configs = {}
+
     @property
     def agent_instances(self) -> List[str]:
         """Agent instance addresses"""
@@ -337,7 +343,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
         """Mock Tendermint update"""
 
         validator_configs = self.state.format_genesis_data(
-            self.state.registered_addresses
+            self.state.initial_tm_configs
         )
         body = json.dumps(validator_configs).encode(self.state.ENCODING)
         url = self.state.tendermint_parameter_url
@@ -376,7 +382,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
     # tests
     def test_init(self) -> None:
         """Empty init"""
-        assert self.state.registered_addresses == {}
+        assert self.state.initial_tm_configs == {}
         assert self.state.local_tendermint_params == {}
         assert self.state.updated_genesis_data == {}
 
@@ -422,6 +428,19 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             log_message = self.state.LogMessages.failed_verification
             assert log_message.value in caplog.text
 
+    def test_on_chain_service_id_not_set(self, caplog: LogCaptureFixture) -> None:
+        """Test `get_addresses` when `on_chain_service_id` is `None`."""
+
+        with as_context(
+            caplog.at_level(logging.INFO, logger=self.logger),
+            self.mocked_service_registry_address,
+        ):
+            self.behaviour.act_wrapper()
+            self.mock_get_local_tendermint_params()
+            self.mock_is_correct_contract()
+            log_message = self.state.LogMessages.no_on_chain_service_id
+            assert log_message.value in caplog.text
+
     def test_failed_service_info(self, caplog: LogCaptureFixture) -> None:
         """Test get service info failure"""
 
@@ -480,13 +499,13 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             self.mock_is_correct_contract()
             self.mock_get_agent_instances(*self.agent_instances)
 
-            assert set(self.state.registered_addresses) == set(self.agent_instances)
-            my_info = self.state.registered_addresses[self.state.context.agent_address]
+            assert set(self.state.initial_tm_configs) == set(self.agent_instances)
+            my_info = self.state.initial_tm_configs[self.state.context.agent_address]
             assert (
                 my_info["hostname"]
                 == urlparse(self.state.context.params.tendermint_url).hostname
             )
-            assert not any(map(self.state.registered_addresses.get, self.other_agents))
+            assert not any(map(self.state.initial_tm_configs.get, self.other_agents))
             log_message = self.state.LogMessages.response_service_info
             assert log_message.value in caplog.text
 
@@ -497,13 +516,18 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             caplog.at_level(logging.INFO, logger=self.logger),
             self.mocked_service_registry_address,
             self.mocked_on_chain_service_id,
+            mock.patch.object(
+                self._skill.skill_context.state,
+                "acn_container",
+                side_effect=lambda: self.agent_instances,
+            ),
         ):
             self.behaviour.act_wrapper()
             self.mock_get_local_tendermint_params()
             self.mock_is_correct_contract()
             self.mock_get_agent_instances(*self.agent_instances)
             self.mock_get_tendermint_info(*self.other_agents)
-            assert all(map(self.state.registered_addresses.get, self.other_agents))
+            assert all(map(self.state.initial_tm_configs.get, self.other_agents))
             log_message = self.state.LogMessages.collection_complete
             assert log_message.value in caplog.text
 
@@ -523,6 +547,11 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             self.mocked_service_registry_address,
             self.mocked_on_chain_service_id,
             self.mocked_yield_from_sleep,
+            mock.patch.object(
+                self._skill.skill_context.state,
+                "acn_container",
+                side_effect=lambda: self.agent_instances,
+            ),
         ):
             self.behaviour.act_wrapper()
             self.mock_get_local_tendermint_params()
@@ -568,6 +597,11 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
                     valid_response
                 ),
             ),
+            mock.patch.object(
+                self._skill.skill_context.state,
+                "acn_container",
+                side_effect=lambda: self.agent_instances,
+            ),
         ):
             self.behaviour.act_wrapper()
             self.mock_get_local_tendermint_params()
