@@ -18,6 +18,7 @@
 # ------------------------------------------------------------------------------
 
 """This module contains the data classes for the `transaction settlement` ABCI application."""
+
 import textwrap
 from abc import ABC
 from collections import deque
@@ -25,19 +26,24 @@ from enum import Enum
 from typing import Deque, Dict, List, Mapping, Optional, Set, Tuple, cast
 
 from packages.valory.skills.abstract_round_abci.base import (
+    ABCIAppInternalError,
     AbciApp,
     AbciAppDB,
     AbciAppTransitionFunction,
     AppState,
     BaseSynchronizedData,
+    BaseTxPayload,
     CollectDifferentUntilThresholdRound,
     CollectNonEmptyUntilThresholdRound,
     CollectSameUntilThresholdRound,
+    CollectionRound,
     DegenerateRound,
     OnlyKeeperSendsRound,
+    TransactionNotValidError,
     VotingRound,
     get_name,
 )
+from packages.valory.skills.abstract_round_abci.utils import filter_negative
 from packages.valory.skills.transaction_settlement_abci.payload_tools import (
     VerificationStatus,
     tx_hist_hex_to_payload,
@@ -74,7 +80,7 @@ class Event(Enum):
     CHECK_HISTORY = "check_history"
     CHECK_LATE_ARRIVING_MESSAGE = "check_late_arriving_message"
     FINALIZATION_FAILED = "finalization_failed"
-    MISSED_AND_LATE_MESSAGES_MISMATCH = "missed_and_late_messages_mismatch"
+    SUSPICIOUS_ACTIVITY = "suspicious_activity"
     INSUFFICIENT_FUNDS = "insufficient_funds"
     INCORRECT_SERIALIZATION = "incorrect_serialization"
 
@@ -91,10 +97,9 @@ class SynchronizedData(
     @property
     def participant_to_signature(self) -> Mapping[str, SignaturePayload]:
         """Get the participant_to_signature."""
-        return cast(
-            Mapping[str, SignaturePayload],
-            self.db.get_strict("participant_to_signature"),
-        )
+        serialized = self.db.get_strict("participant_to_signature")
+        deserialized = CollectionRound.deserialize_collection(serialized)
+        return cast(Mapping[str, SignaturePayload], deserialized)
 
     @property
     def tx_hashes_history(self) -> List[str]:
@@ -119,6 +124,12 @@ class SynchronizedData(
         malicious_threshold = self.nb_participants // 3
         return len(self.keepers) > malicious_threshold
 
+    @property
+    def most_voted_randomness_round(self) -> int:  # pragma: no cover
+        """Get the first in priority keeper to try to re-submit a transaction."""
+        round_ = self.db.get_strict("most_voted_randomness_round")
+        return cast(int, round_)
+
     @property
     def most_voted_keeper_address(self) -> str:
         """Get the first in priority keeper to try to re-submit a transaction."""
@@ -167,10 +178,10 @@ class SynchronizedData(
     @property
     def final_verification_status(self) -> VerificationStatus:
         """Get the final verification status."""
-        return cast(
-            VerificationStatus,
-            self.db.get("final_verification_status", VerificationStatus.NOT_VERIFIED),
-        )
+        status_value = self.db.get("final_verification_status", None)
+        if status_value is None:
+            return VerificationStatus.NOT_VERIFIED
+        return VerificationStatus(status_value)
 
     @property
     def most_voted_tx_hash(self) -> str:
@@ -178,21 +189,38 @@ class SynchronizedData(
         return cast(str, self.db.get_strict("most_voted_tx_hash"))
 
     @property
-    def missed_messages(self) -> int:
-        """Check the number of missed messages."""
-        return cast(int, self.db.get("missed_messages", 0))
+    def missed_messages(self) -> Dict[str, int]:
+        """The number of missed messages per agent address."""
+        default = dict.fromkeys(self.all_participants, 0)
+        missed_messages = self.db.get("missed_messages", default)
+        return cast(Dict[str, int], missed_messages)
+
+    @property
+    def n_missed_messages(self) -> int:
+        """The number of missed messages in total."""
+        return sum(self.missed_messages.values())
 
     @property
     def should_check_late_messages(self) -> bool:
         """Check if we should check for late-arriving messages."""
-        return self.missed_messages > 0
+        return self.n_missed_messages > 0
 
     @property
-    def late_arriving_tx_hashes(self) -> List[str]:
+    def late_arriving_tx_hashes(self) -> Dict[str, List[str]]:
         """Get the late_arriving_tx_hashes."""
-        late_arrivals = cast(List[str], self.db.get_strict("late_arriving_tx_hashes"))
-        parsed_hashes = map(lambda h: textwrap.wrap(h, TX_HASH_LENGTH), late_arrivals)
-        return [h for hashes in parsed_hashes for h in hashes]
+        late_arrivals = cast(
+            Dict[str, str], self.db.get_strict("late_arriving_tx_hashes")
+        )
+        parsed_hashes = {
+            sender: textwrap.wrap(hashes, TX_HASH_LENGTH)
+            for sender, hashes in late_arrivals.items()
+        }
+        return parsed_hashes
+
+    @property
+    def suspects(self) -> Tuple[str]:
+        """Get the suspect agents."""
+        return cast(Tuple[str], self.db.get("suspects", tuple()))
 
     @property
     def most_voted_check_result(self) -> str:  # pragma: no cover
@@ -204,10 +232,18 @@ class SynchronizedData(
         self,
     ) -> Mapping[str, CheckTransactionHistoryPayload]:  # pragma: no cover
         """Get the mapping from participants to checks."""
-        return cast(
-            Mapping[str, CheckTransactionHistoryPayload],
-            self.db.get_strict("participant_to_check"),
-        )
+        serialized = self.db.get_strict("participant_to_check")
+        deserialized = CollectionRound.deserialize_collection(serialized)
+        return cast(Mapping[str, CheckTransactionHistoryPayload], deserialized)
+
+    @property
+    def participant_to_late_messages(
+        self,
+    ) -> Mapping[str, SynchronizeLateMessagesPayload]:  # pragma: no cover
+        """Get the mapping from participants to checks."""
+        serialized = self.db.get_strict("participant_to_late_message")
+        deserialized = CollectionRound.deserialize_collection(serialized)
+        return cast(Mapping[str, SynchronizeLateMessagesPayload], deserialized)
 
 
 class FailedRound(DegenerateRound, ABC):
@@ -218,7 +254,6 @@ class CollectSignatureRound(CollectDifferentUntilThresholdRound):
     """A round in which agents sign the transaction"""
 
     payload_class = SignaturePayload
-    payload_attribute = "signature"
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
     no_majority_event = Event.NO_MAJORITY
@@ -228,40 +263,42 @@ class CollectSignatureRound(CollectDifferentUntilThresholdRound):
 class FinalizationRound(OnlyKeeperSendsRound):
     """A round that represents transaction signing has finished"""
 
+    keeper_payload: Optional[FinalizationTxPayload] = None
     payload_class = FinalizationTxPayload
-    payload_attribute = "tx_data"
     synchronized_data_class = SynchronizedData
 
-    def end_block(
+    def end_block(  # pylint: disable=too-many-return-statements
         self,
     ) -> Optional[
         Tuple[BaseSynchronizedData, Enum]
     ]:  # pylint: disable=too-many-return-statements
         """Process the end of the block."""
-        if not self.has_keeper_sent_payload:
+        if self.keeper_payload is None:
             return None
 
-        if self.keeper_payload is None:  # pragma: no cover
+        if self.keeper_payload.tx_data is None:
             return self.synchronized_data, Event.FINALIZATION_FAILED
 
-        verification_status = VerificationStatus(self.keeper_payload["status_value"])
+        verification_status = VerificationStatus(
+            self.keeper_payload.tx_data["status_value"]
+        )
         synchronized_data = cast(
             SynchronizedData,
             self.synchronized_data.update(
                 synchronized_data_class=self.synchronized_data_class,
                 **{
-                    get_name(SynchronizedData.tx_hashes_history): self.keeper_payload[
-                        "tx_hashes_history"
-                    ],
+                    get_name(
+                        SynchronizedData.tx_hashes_history
+                    ): self.keeper_payload.tx_data["tx_hashes_history"],
                     get_name(
                         SynchronizedData.final_verification_status
-                    ): verification_status,
-                    get_name(SynchronizedData.keepers): self.keeper_payload[
+                    ): verification_status.value,
+                    get_name(SynchronizedData.keepers): self.keeper_payload.tx_data[
                         "serialized_keepers"
                     ],
-                    get_name(SynchronizedData.blacklisted_keepers): self.keeper_payload[
-                        "blacklisted_keepers"
-                    ],
+                    get_name(
+                        SynchronizedData.blacklisted_keepers
+                    ): self.keeper_payload.tx_data["blacklisted_keepers"],
                 },
             ),
         )
@@ -271,7 +308,7 @@ class FinalizationRound(OnlyKeeperSendsRound):
         # 1. Getting raw safe transaction.
         # 2. Requesting transaction signature.
         # 3. Requesting transaction digest.
-        if self.keeper_payload["received_hash"]:
+        if self.keeper_payload.tx_data["received_hash"]:
             return synchronized_data, Event.DONE
         # If keeper has been blacklisted, return an `INSUFFICIENT_FUNDS` event.
         if verification_status == VerificationStatus.INSUFFICIENT_FUNDS:
@@ -297,19 +334,20 @@ class RandomnessTransactionSubmissionRound(CollectSameUntilThresholdRound):
     """A round for generating randomness"""
 
     payload_class = RandomnessPayload
-    payload_attribute = "randomness"
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
     no_majority_event = Event.NO_MAJORITY
     collection_key = get_name(SynchronizedData.participant_to_randomness)
-    selection_key = get_name(SynchronizedData.most_voted_randomness)
+    selection_key = (
+        get_name(SynchronizedData.most_voted_randomness_round),
+        get_name(SynchronizedData.most_voted_randomness),
+    )
 
 
 class SelectKeeperTransactionSubmissionRoundA(CollectSameUntilThresholdRound):
     """A round in which a keeper is selected for transaction submission"""
 
     payload_class = SelectKeeperPayload
-    payload_attribute = "keepers"
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
     no_majority_event = Event.NO_MAJORITY
@@ -342,16 +380,16 @@ class SelectKeeperTransactionSubmissionRoundBAfterTimeout(
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
         """Process the end of the block."""
         if self.threshold_reached:
+            synchronized_data = cast(SynchronizedData, self.synchronized_data)
+            keeper = synchronized_data.most_voted_keeper_address
+            missed_messages = synchronized_data.missed_messages
+            missed_messages[keeper] += 1
+
             synchronized_data = cast(
                 SynchronizedData,
                 self.synchronized_data.update(
                     synchronized_data_class=self.synchronized_data_class,
-                    **{
-                        get_name(SynchronizedData.missed_messages): cast(
-                            SynchronizedData, self.synchronized_data
-                        ).missed_messages
-                        + 1
-                    },
+                    **{get_name(SynchronizedData.missed_messages): missed_messages},
                 ),
             )
             if synchronized_data.keepers_threshold_exceeded:
@@ -367,7 +405,6 @@ class ValidateTransactionRound(VotingRound):
     """A round in which agents validate the transaction"""
 
     payload_class = ValidatePayload
-    payload_attribute = "vote"
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
     negative_event = Event.NEGATIVE
@@ -394,10 +431,10 @@ class ValidateTransactionRound(VotingRound):
             synchronized_data = self.synchronized_data.update(
                 synchronized_data_class=self.synchronized_data_class,
                 **{
-                    self.collection_key: self.collection,
+                    self.collection_key: self.serialized_collection,
                     get_name(
                         SynchronizedData.final_verification_status
-                    ): VerificationStatus.VERIFIED,
+                    ): VerificationStatus.VERIFIED.value,
                     get_name(SynchronizedData.final_tx_hash): final_tx_hash,
                 },
             )
@@ -417,7 +454,6 @@ class CheckTransactionHistoryRound(CollectSameUntilThresholdRound):
     """A round in which agents check the transaction history to see if any previous tx has been validated"""
 
     payload_class = CheckTransactionHistoryPayload
-    payload_attribute = "verified_res"
     synchronized_data_class = SynchronizedData
     collection_key = get_name(SynchronizedData.participant_to_check)
     selection_key = get_name(SynchronizedData.most_voted_check_result)
@@ -439,11 +475,11 @@ class CheckTransactionHistoryRound(CollectSameUntilThresholdRound):
                 synchronized_data = self.synchronized_data.update(
                     synchronized_data_class=self.synchronized_data_class,
                     **{
-                        self.collection_key: self.collection,
+                        self.collection_key: self.serialized_collection,
                         self.selection_key: self.most_voted_payload,
                         get_name(
                             SynchronizedData.final_verification_status
-                        ): return_status,
+                        ): return_status.value,
                         get_name(SynchronizedData.final_tx_hash): return_tx_hash,
                     },
                 )
@@ -477,12 +513,13 @@ class SynchronizeLateMessagesRound(CollectNonEmptyUntilThresholdRound):
     """A round in which agents synchronize potentially late arriving messages"""
 
     payload_class = SynchronizeLateMessagesPayload
-    payload_attribute = "tx_hashes"
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
-    no_majority_event = Event.NO_MAJORITY
     none_event = Event.NONE
-    collection_key = get_name(SynchronizedData.late_arriving_tx_hashes)
+    required_block_confirmations = 3
+    selection_key = get_name(SynchronizedData.late_arriving_tx_hashes)
+    collection_key = get_name(SynchronizedData.participant_to_late_messages)
+    # if the payload is serialized to bytes, we verify that the length specified matches
     _hash_length = TX_HASH_LENGTH
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
@@ -491,20 +528,61 @@ class SynchronizeLateMessagesRound(CollectNonEmptyUntilThresholdRound):
         if result is None:
             return None
 
-        synchronized_data, event = cast(Tuple[BaseSynchronizedData, Event], result)
+        synchronized_data, event = cast(Tuple[SynchronizedData, Event], result)
 
-        synchronized_data = cast(SynchronizedData, self.synchronized_data)
-        n_late_arriving_tx_hashes = len(synchronized_data.late_arriving_tx_hashes)
-        if n_late_arriving_tx_hashes > synchronized_data.missed_messages:
-            return synchronized_data, Event.MISSED_AND_LATE_MESSAGES_MISMATCH
+        late_arriving_tx_hashes_counts = {
+            sender: len(hashes)
+            for sender, hashes in synchronized_data.late_arriving_tx_hashes.items()
+        }
+        missed_after_sync = {
+            sender: missed - late_arriving_tx_hashes_counts.get(sender, 0)
+            for sender, missed in synchronized_data.missed_messages.items()
+        }
+        suspects = tuple(filter_negative(missed_after_sync))
 
-        still_missing = synchronized_data.missed_messages - n_late_arriving_tx_hashes
-        synchronized_data = synchronized_data.update(
-            synchronized_data_class=self.synchronized_data_class,
-            **{get_name(SynchronizedData.missed_messages): still_missing},
+        if suspects:
+            synchronized_data = cast(
+                SynchronizedData,
+                synchronized_data.update(
+                    synchronized_data_class=self.synchronized_data_class,
+                    **{get_name(SynchronizedData.suspects): suspects},
+                ),
+            )
+            return synchronized_data, Event.SUSPICIOUS_ACTIVITY
+
+        synchronized_data = cast(
+            SynchronizedData,
+            synchronized_data.update(
+                synchronized_data_class=self.synchronized_data_class,
+                **{get_name(SynchronizedData.missed_messages): missed_after_sync},
+            ),
         )
         return synchronized_data, event
 
+    def process_payload(self, payload: BaseTxPayload) -> None:
+        """Process payload."""
+        # TODO: move check into payload definition via `post_init`
+        payload = cast(SynchronizeLateMessagesPayload, payload)
+        if self._hash_length:
+            content = payload.tx_hashes
+            if not content or len(content) % self._hash_length:
+                msg = f"Expecting serialized data of chunk size {self._hash_length}"
+                raise ABCIAppInternalError(f"{msg}, got: {content} in {self.round_id}")
+        super().process_payload(payload)
+
+    def check_payload(self, payload: BaseTxPayload) -> None:
+        """Check Payload"""
+        # TODO: move check into payload definition via `post_init`
+        payload = cast(SynchronizeLateMessagesPayload, payload)
+        if self._hash_length:
+            content = payload.tx_hashes
+            if not content or len(content) % self._hash_length:
+                msg = f"Expecting serialized data of chunk size {self._hash_length}"
+                raise TransactionNotValidError(
+                    f"{msg}, got: {content} in {self.round_id}"
+                )
+        super().check_payload(payload)
+
 
 class FinishedTransactionSubmissionRound(DegenerateRound, ABC):
     """A round that represents the transition to the ResetAndPauseRound"""
@@ -514,7 +592,6 @@ class ResetRound(CollectSameUntilThresholdRound):
     """A round that represents the reset of a period"""
 
     payload_class = ResetPayload
-    payload_attribute = "period_count"
     synchronized_data_class = SynchronizedData
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
@@ -589,9 +666,8 @@ class TransactionSubmissionAbciApp(AbciApp[Event]):
         8. SynchronizeLateMessagesRound
             - done: 9.
             - round timeout: 8.
-            - no majority: 8.
             - none: 6.
-            - missed and late messages mismatch: 12.
+            - suspicious activity: 12.
         9. CheckLateTxHashesRound
             - done: 11.
             - negative: 12.
@@ -675,9 +751,8 @@ class TransactionSubmissionAbciApp(AbciApp[Event]):
         SynchronizeLateMessagesRound: {
             Event.DONE: CheckLateTxHashesRound,
             Event.ROUND_TIMEOUT: SynchronizeLateMessagesRound,
-            Event.NO_MAJORITY: SynchronizeLateMessagesRound,
             Event.NONE: SelectKeeperTransactionSubmissionRoundB,
-            Event.MISSED_AND_LATE_MESSAGES_MISMATCH: FailedRound,
+            Event.SUSPICIOUS_ACTIVITY: FailedRound,
         },
         CheckLateTxHashesRound: {
             Event.DONE: FinishedTransactionSubmissionRound,
@@ -706,16 +781,16 @@ class TransactionSubmissionAbciApp(AbciApp[Event]):
         Event.CHECK_TIMEOUT: 30.0,
         Event.RESET_TIMEOUT: 30.0,
     }
-    db_pre_conditions: Dict[AppState, List[str]] = {
-        RandomnessTransactionSubmissionRound: [
+    db_pre_conditions: Dict[AppState, Set[str]] = {
+        RandomnessTransactionSubmissionRound: {
             get_name(SynchronizedData.most_voted_tx_hash),
             get_name(SynchronizedData.participants),
-        ]
+        }
     }
-    db_post_conditions: Dict[AppState, List[str]] = {
-        FinishedTransactionSubmissionRound: [
+    db_post_conditions: Dict[AppState, Set[str]] = {
+        FinishedTransactionSubmissionRound: {
             get_name(SynchronizedData.final_tx_hash),
             get_name(SynchronizedData.final_verification_status),
-        ],
-        FailedRound: [],
+        },
+        FailedRound: set(),
     }
