@@ -538,29 +538,53 @@ class TestSelectKeeperTransactionSubmissionBehaviourB(
         "keeper_retries",
         new_callable=mock.PropertyMock,
     )
+    @mock.patch.object(
+        TransactionSettlementSynchronizedSata,
+        "final_verification_status",
+        new_callable=mock.PropertyMock,
+    )
     @pytest.mark.parametrize(
-        "keepers, keeper_retries, blacklisted_keepers",
+        "keepers, keeper_retries, blacklisted_keepers, final_verification_status",
         (
-            (deque(f"keeper_{i}" for i in range(4)), 1, set()),
-            (deque(("test_keeper",)), 2, set()),
-            (deque(("test_keeper",)), 2, {"a1"}),
-            (deque(("test_keeper",)), 2, {"test_keeper"}),
-            (deque(("test_keeper",)), 2, {"a_1", "a_2", "test_keeper"}),
-            (deque(("test_keeper",)), 1, set()),
-            (deque(("test_keeper",)), 3, set()),
+            (
+                deque(f"keeper_{i}" for i in range(4)),
+                1,
+                set(),
+                VerificationStatus.NOT_VERIFIED,
+            ),
+            (deque(("test_keeper",)), 2, set(), VerificationStatus.PENDING),
+            (deque(("test_keeper",)), 2, set(), VerificationStatus.NOT_VERIFIED),
+            (deque(("test_keeper",)), 2, {"a1"}, VerificationStatus.NOT_VERIFIED),
+            (
+                deque(("test_keeper",)),
+                2,
+                {"test_keeper"},
+                VerificationStatus.NOT_VERIFIED,
+            ),
+            (
+                deque(("test_keeper",)),
+                2,
+                {"a_1", "a_2", "test_keeper"},
+                VerificationStatus.NOT_VERIFIED,
+            ),
+            (deque(("test_keeper",)), 1, set(), VerificationStatus.NOT_VERIFIED),
+            (deque(("test_keeper",)), 3, set(), VerificationStatus.NOT_VERIFIED),
         ),
     )
     def test_select_keeper(
         self,
+        final_verification_status_mock: mock.PropertyMock,
         keeper_retries_mock: mock.PropertyMock,
         keepers_mock: mock.PropertyMock,
         keepers: Deque[str],
         keeper_retries: int,
         blacklisted_keepers: Set[str],
+        final_verification_status: VerificationStatus,
     ) -> None:
         """Test select keeper agent."""
         keepers_mock.return_value = keepers
         keeper_retries_mock.return_value = keeper_retries
+        final_verification_status_mock.return_value = final_verification_status
         super().test_select_keeper(blacklisted_keepers=blacklisted_keepers)
 
     @mock.patch.object(
@@ -636,7 +660,7 @@ class TestFinalizeBehaviour(TransactionSettlementFSMBehaviourBaseCase):
         self,
     ) -> None:
         """Test finalize behaviour."""
-        participants = frozenset({self.skill.skill_context.agent_address, "a_1", "a_2"})
+        participants = (self.skill.skill_context.agent_address, "a_1", "a_2")
         retries = 1
         self.fast_forward_to_behaviour(
             behaviour=self.behaviour,
@@ -760,8 +784,10 @@ class TestFinalizeBehaviour(TransactionSettlementFSMBehaviourBaseCase):
         # keepers need to have length == 42 in order to be parsed
         agent_address_mock.return_value = "-" * 42
         retries = 1
-        participants = frozenset(
-            {self.skill.skill_context.agent_address, "a_1" + "-" * 39, "a_2" + "-" * 39}
+        participants = (
+            self.skill.skill_context.agent_address,
+            "a_1" + "-" * 39,
+            "a_2" + "-" * 39,
         )
         self.fast_forward_to_behaviour(
             behaviour=self.behaviour,
@@ -853,8 +879,10 @@ class TestFinalizeBehaviour(TransactionSettlementFSMBehaviourBaseCase):
         max_priority_fee_per_gas: Optional[int] = None
 
         retries = 1
-        participants = frozenset(
-            {self.skill.skill_context.agent_address, "a_1" + "-" * 39, "a_2" + "-" * 39}
+        participants = (
+            self.skill.skill_context.agent_address,
+            "a_1" + "-" * 39,
+            "a_2" + "-" * 39,
         )
         kwargs = dict(
             safe_contract_address="safe_contract_address",
@@ -931,7 +959,7 @@ class TestFinalizeBehaviour(TransactionSettlementFSMBehaviourBaseCase):
 
     def test_handle_late_messages(self) -> None:
         """Test `handle_late_messages.`"""
-        participants = frozenset({self.skill.skill_context.agent_address, "a_1", "a_2"})
+        participants = (self.skill.skill_context.agent_address, "a_1", "a_2")
         self.fast_forward_to_behaviour(
             behaviour=self.behaviour,
             behaviour_id=self.behaviour_class.auto_behaviour_id(),
@@ -941,7 +969,7 @@ class TestFinalizeBehaviour(TransactionSettlementFSMBehaviourBaseCase):
                         dict(
                             most_voted_keeper_address="most_voted_keeper_address",
                             participants=participants,
-                            keepers=deque([self.skill.skill_context.agent_address]),
+                            keepers="keepers",
                         )
                     ),
                 )
@@ -986,7 +1014,7 @@ class TestValidateTransactionBehaviour(TransactionSettlementFSMBehaviourBaseCase
 
     def _fast_forward(self) -> None:
         """Fast-forward to relevant behaviour."""
-        participants = frozenset({self.skill.skill_context.agent_address, "a_1", "a_2"})
+        participants = (self.skill.skill_context.agent_address, "a_1", "a_2")
         most_voted_keeper_address = self.skill.skill_context.agent_address
         self.fast_forward_to_behaviour(
             behaviour=self.behaviour,
@@ -1097,8 +1125,10 @@ class TestCheckTransactionHistoryBehaviour(TransactionSettlementFSMBehaviourBase
                     setup_data=AbciAppDB.data_to_lists(
                         dict(
                             safe_contract_address="safe_contract_address",
-                            participants=frozenset(
-                                {self.skill.skill_context.agent_address, "a_1", "a_2"}
+                            participants=(
+                                self.skill.skill_context.agent_address,
+                                "a_1",
+                                "a_2",
                             ),
                             participant_to_signature={},
                             most_voted_tx_hash="b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d900000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000002625a000x77E9b2EF921253A171Fa0CB9ba80558648Ff7215b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
@@ -1184,13 +1214,13 @@ class TestCheckTransactionHistoryBehaviour(TransactionSettlementFSMBehaviourBase
 class TestCheckLateTxHashesBehaviour(TransactionSettlementFSMBehaviourBaseCase):
     """Test CheckLateTxHashesBehaviour."""
 
-    def _fast_forward(self, late_arriving_tx_hashes: str) -> None:
+    def _fast_forward(self, late_arriving_tx_hashes: Dict[str, str]) -> None:
         """Fast-forward to relevant behaviour."""
 
         agent_address = self.skill.skill_context.agent_address
         kwargs = dict(
             safe_contract_address="safe_contract_address",
-            participants=frozenset({agent_address, "a_1", "a_2"}),
+            participants=(agent_address, "a_1", "a_2"),
             participant_to_signature={},
             most_voted_tx_hash="",
             late_arriving_tx_hashes=late_arriving_tx_hashes,
@@ -1209,8 +1239,7 @@ class TestCheckLateTxHashesBehaviour(TransactionSettlementFSMBehaviourBaseCase):
 
     def test_check_tx_history_behaviour(self) -> None:
         """Test CheckTransactionHistoryBehaviour."""
-
-        self._fast_forward(late_arriving_tx_hashes="")
+        self._fast_forward(late_arriving_tx_hashes={})
         self.behaviour.act_wrapper()
         self.behaviour.act_wrapper()
         self.mock_a2a_transaction()
@@ -1239,7 +1268,7 @@ class TestSynchronizeLateMessagesBehaviour(TransactionSettlementFSMBehaviourBase
             TransactionSettlementBaseBehaviour, self.behaviour.current_behaviour
         ).params.mutable_params.late_messages = late_messages
 
-        participants = frozenset({self.skill.skill_context.agent_address, "a_1", "a_2"})
+        participants = (self.skill.skill_context.agent_address, "a_1", "a_2")
         self.fast_forward_to_behaviour(
             behaviour=self.behaviour,
             behaviour_id=SynchronizeLateMessagesBehaviour.auto_behaviour_id(),
