@@ -49,6 +49,7 @@ from packages.valory.skills.abstract_round_abci.base import (
 from packages.valory.skills.abstract_round_abci.base import (
     BaseTxPayload,
     CollectSameUntilThresholdRound,
+    CollectionRound,
     MAX_INT_256,
     TransactionNotValidError,
     VotingRound,
@@ -162,6 +163,15 @@ def get_participant_to_votes(
     }
 
 
+def get_participant_to_votes_serialized(
+    participants: FrozenSet[str], vote: Optional[bool] = True
+) -> Dict[str, Dict[str, Any]]:
+    """participant_to_votes"""
+    return CollectionRound.serialize_collection(
+        get_participant_to_votes(participants, vote)
+    )
+
+
 def get_most_voted_tx_hash() -> str:
     """most_voted_tx_hash"""
     return "tx_hash"
@@ -209,16 +219,26 @@ def get_participant_to_late_arriving_tx_hashes(
     }
 
 
-def get_late_arriving_tx_hashes() -> List[str]:
+def get_late_arriving_tx_hashes_deserialized() -> Dict[str, List[str]]:
     """Get dummy late-arriving tx hashes."""
     # We want the tx hashes to have a size which can be divided by 64 to be able to parse it.
     # Otherwise, they are not valid.
-    return [
-        "t" * TX_HASH_LENGTH,
-        "e" * TX_HASH_LENGTH,
-        "s" * TX_HASH_LENGTH,
-        "t" * TX_HASH_LENGTH,
-    ]
+    return {
+        "sender": [
+            "t" * TX_HASH_LENGTH,
+            "e" * TX_HASH_LENGTH,
+            "s" * TX_HASH_LENGTH,
+            "t" * TX_HASH_LENGTH,
+        ]
+    }
+
+
+def get_late_arriving_tx_hashes_serialized() -> Dict[str, str]:
+    """Get dummy late-arriving tx hashes."""
+    # We want the tx hashes to have a size which can be divided by 64 to be able to parse it.
+    # Otherwise, they are not valid.
+    deserialized = get_late_arriving_tx_hashes_deserialized()
+    return {sender: "".join(hash_) for sender, hash_ in deserialized.items()}
 
 
 def get_keepers(keepers: Deque[str], retries: int = 1) -> str:
@@ -241,7 +261,6 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
 
         test_round = self.test_class(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -249,8 +268,8 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
                 test_round=test_round,
                 round_payloads=get_participant_to_votes(self.participants),
                 synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.update(
-                    participant_to_votes=dict(
-                        get_participant_to_votes(self.participants)
+                    participant_to_votes=get_participant_to_votes_serialized(
+                        self.participants
                     )
                 ),
                 synchronized_data_attr_checks=[
@@ -267,7 +286,6 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
 
         test_round = self.test_class(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -275,8 +293,8 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
                 test_round=test_round,
                 round_payloads=get_participant_to_votes(self.participants, vote=False),
                 synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.update(
-                    participant_to_votes=dict(
-                        get_participant_to_votes(self.participants, vote=False)
+                    participant_to_votes=get_participant_to_votes_serialized(
+                        self.participants, vote=False
                     )
                 ),
                 synchronized_data_attr_checks=[],
@@ -291,7 +309,6 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
 
         test_round = self.test_class(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -299,8 +316,8 @@ class BaseValidateRoundTest(BaseVotingRoundTest):
                 test_round=test_round,
                 round_payloads=get_participant_to_votes(self.participants, vote=None),
                 synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.update(
-                    participant_to_votes=dict(
-                        get_participant_to_votes(self.participants, vote=None)
+                    participant_to_votes=get_participant_to_votes_serialized(
+                        self.participants, vote=None
                     )
                 ),
                 synchronized_data_attr_checks=[],
@@ -335,7 +352,6 @@ class BaseSelectKeeperRoundTest(BaseCollectSameUntilThresholdRoundTest):
             synchronized_data=self.synchronized_data.update(
                 keepers=keepers,
             ),
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -345,7 +361,7 @@ class BaseSelectKeeperRoundTest(BaseCollectSameUntilThresholdRoundTest):
                     self.participants, most_voted_payload
                 ),
                 synchronized_data_update_fn=lambda _synchronized_data, _test_round: _synchronized_data.update(
-                    participant_to_selection=dict(
+                    participant_to_selection=CollectionRound.serialize_collection(
                         self._participant_to_selection(
                             self.participants, most_voted_payload
                         )
@@ -370,13 +386,6 @@ class TestSelectKeeperTransactionSubmissionRoundA(BaseSelectKeeperRoundTest):
     _synchronized_data_class = TransactionSettlementSynchronizedSata
     _event_class = TransactionSettlementEvent
 
-    @staticmethod
-    def _participant_to_selection(
-        participants: FrozenSet[str], keepers: str
-    ) -> Mapping[str, BaseTxPayload]:
-        """Get participant to selection"""
-        return get_participant_to_selection(participants, keepers)
-
     @pytest.mark.parametrize(
         "most_voted_payload, keepers, exit_event",
         (
@@ -449,13 +458,16 @@ class TestSelectKeeperTransactionSubmissionRoundBAfterTimeout(
         "keepers_threshold_exceeded",
         new_callable=mock.PropertyMock,
     )
+    @pytest.mark.parametrize(
+        "keepers", (f"{int(1).to_bytes(32, 'big').hex()}keeper" + "-" * 36,)
+    )
     @pytest.mark.parametrize(
         "attrs, threshold_exceeded, exit_event",
         (
             (
                 {
                     "tx_hashes_history": "t" * 66,
-                    "missed_messages": 10,
+                    "missed_messages": {f"keeper{'-' * 36}": 10},
                 },
                 True,
                 # Since the threshold has been exceeded, we should return a `CHECK_HISTORY` event.
@@ -463,14 +475,14 @@ class TestSelectKeeperTransactionSubmissionRoundBAfterTimeout(
             ),
             (
                 {
-                    "missed_messages": 10,
+                    "missed_messages": {f"keeper{'-' * 36}": 10},
                 },
                 True,
                 TransactionSettlementEvent.CHECK_LATE_ARRIVING_MESSAGE,
             ),
             (
                 {
-                    "missed_messages": 10,
+                    "missed_messages": {f"keeper{'-' * 36}": 10},
                 },
                 False,
                 TransactionSettlementEvent.DONE,
@@ -480,6 +492,7 @@ class TestSelectKeeperTransactionSubmissionRoundBAfterTimeout(
     def test_run(
         self,
         threshold_exceeded_mock: mock.PropertyMock,
+        keepers: str,
         attrs: Dict[str, Union[str, int]],
         threshold_exceeded: bool,
         exit_event: TransactionSettlementEvent,
@@ -488,14 +501,15 @@ class TestSelectKeeperTransactionSubmissionRoundBAfterTimeout(
         self.synchronized_data.update(participant_to_selection=dict.fromkeys(self.participants), **attrs)  # type: ignore
         threshold_exceeded_mock.return_value = threshold_exceeded
         most_voted_payload = int(1).to_bytes(32, "big").hex() + "new_keeper" + "-" * 32
-        keeper = ""
-        super().test_run(most_voted_payload, keeper, exit_event)
-        assert (
-            cast(
-                TransactionSettlementSynchronizedSata, self.synchronized_data
-            ).missed_messages
-            == cast(int, attrs["missed_messages"]) + 1
+        super().test_run(most_voted_payload, keepers, exit_event)
+        initial_missed_messages = cast(Dict[str, int], (attrs["missed_messages"]))
+        expected_missed_messages = {
+            sender: missed + 1 for sender, missed in initial_missed_messages.items()
+        }
+        synchronized_data = cast(
+            TransactionSettlementSynchronizedSata, self.synchronized_data
         )
+        assert synchronized_data.missed_messages == expected_missed_messages
 
 
 class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
@@ -511,56 +525,56 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
             (
                 "",
                 "",
-                1,
+                {"test": 1},
                 VerificationStatus.ERROR.value,
                 TransactionSettlementEvent.CHECK_LATE_ARRIVING_MESSAGE,
             ),
             (
                 "",
                 "",
-                0,
+                {},
                 VerificationStatus.ERROR.value,
                 TransactionSettlementEvent.FINALIZATION_FAILED,
             ),
             (
                 "t" * 66,
                 "",
-                0,
+                {},
                 VerificationStatus.VERIFIED.value,
                 TransactionSettlementEvent.CHECK_HISTORY,
             ),
             (
                 "t" * 66,
                 "",
-                0,
+                {},
                 VerificationStatus.ERROR.value,
                 TransactionSettlementEvent.CHECK_HISTORY,
             ),
             (
                 "",
                 "",
-                0,
+                {},
                 VerificationStatus.PENDING.value,
                 TransactionSettlementEvent.FINALIZATION_FAILED,
             ),
             (
                 "",
                 "tx_digest" + "t" * 57,
-                0,
+                {},
                 VerificationStatus.PENDING.value,
                 TransactionSettlementEvent.DONE,
             ),
             (
                 "t" * 66,
                 "tx_digest" + "t" * 57,
-                0,
+                {},
                 VerificationStatus.PENDING.value,
                 TransactionSettlementEvent.DONE,
             ),
             (
                 "t" * 66,
                 "",
-                0,
+                {},
                 VerificationStatus.INSUFFICIENT_FUNDS.value,
                 TransactionSettlementEvent.INSUFFICIENT_FUNDS,
             ),
@@ -582,7 +596,7 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
         self.synchronized_data = cast(
             TransactionSettlementSynchronizedSata,
             self.synchronized_data.update(
-                participants=frozenset([f"agent_{i}" + "-" * 35 for i in range(4)]),
+                participants=tuple(self.participants),
                 missed_messages=missed_messages,
                 tx_hashes_history=tx_hashes_history,
                 keepers=get_keepers(keepers, keeper_retries),
@@ -603,7 +617,6 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
 
         test_round = self._round_class(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -624,7 +637,7 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
                     blacklisted_keepers=blacklisted_keepers,
                     keepers=get_keepers(keepers, keeper_retries),
                     keeper_retries=keeper_retries,
-                    final_verification_status=VerificationStatus(status),
+                    final_verification_status=VerificationStatus(status).value,
                 ),
                 synchronized_data_attr_checks=[
                     lambda _synchronized_data: _synchronized_data.tx_hashes_history,
@@ -637,6 +650,43 @@ class TestFinalizationRound(BaseOnlyKeeperSendsRoundTest):
             )
         )
 
+    def test_finalization_round_no_tx_data(self) -> None:
+        """Test finalization round when `tx_data` is `None`."""
+        keepers = deque(("agent_1" + "-" * 35, "agent_3" + "-" * 35))
+        keeper_retries = 2
+        self.synchronized_data = cast(
+            TransactionSettlementSynchronizedSata,
+            self.synchronized_data.update(
+                participants=tuple(f"agent_{i}" + "-" * 35 for i in range(4)),
+                keepers=get_keepers(keepers, keeper_retries),
+            ),
+        )
+
+        sender = keepers[0]
+
+        test_round = self._round_class(
+            synchronized_data=self.synchronized_data,
+        )
+
+        self._complete_run(
+            self._test_round(
+                test_round=test_round,
+                keeper_payloads=FinalizationTxPayload(
+                    sender=sender,
+                    tx_data=None,
+                ),
+                synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data,
+                synchronized_data_attr_checks=[
+                    lambda _synchronized_data: _synchronized_data.tx_hashes_history,
+                    lambda _synchronized_data: _synchronized_data.blacklisted_keepers,
+                    lambda _synchronized_data: _synchronized_data.keepers,
+                    lambda _synchronized_data: _synchronized_data.keeper_retries,
+                    lambda _synchronized_data: _synchronized_data.final_verification_status,
+                ],
+                exit_event=TransactionSettlementEvent.FINALIZATION_FAILED,
+            )
+        )
+
 
 class TestCollectSignatureRound(BaseCollectDifferentUntilThresholdRoundTest):
     """Test CollectSignatureRound."""
@@ -651,7 +701,6 @@ class TestCollectSignatureRound(BaseCollectDifferentUntilThresholdRoundTest):
 
         test_round = CollectSignatureRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -664,14 +713,6 @@ class TestCollectSignatureRound(BaseCollectDifferentUntilThresholdRoundTest):
             )
         )
 
-    def test_no_majority_event(self) -> None:
-        """Test the no-majority event."""
-        test_round = CollectSignatureRound(
-            self.synchronized_data, self.consensus_params
-        )
-        test_round.block_confirmations = test_round.required_block_confirmations + 1
-        self._test_no_majority_event(test_round)
-
 
 class TestValidateTransactionRound(BaseValidateRoundTest):
     """Test ValidateRound."""
@@ -693,25 +734,25 @@ class TestCheckTransactionHistoryRound(BaseCollectSameUntilThresholdRoundTest):
             (
                 "0000000000000000000000000000000000000000000000000000000000000001",
                 "b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
-                0,
+                {},
                 TransactionSettlementEvent.DONE,
             ),
             (
                 "0000000000000000000000000000000000000000000000000000000000000002",
                 "b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
-                0,
+                {},
                 TransactionSettlementEvent.NEGATIVE,
             ),
             (
                 "0000000000000000000000000000000000000000000000000000000000000003",
                 "b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
-                0,
+                {},
                 TransactionSettlementEvent.NONE,
             ),
             (
                 "0000000000000000000000000000000000000000000000000000000000000002",
                 "b0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
-                1,
+                {"test": 1},
                 TransactionSettlementEvent.CHECK_LATE_ARRIVING_MESSAGE,
             ),
         ),
@@ -729,7 +770,6 @@ class TestCheckTransactionHistoryRound(BaseCollectSameUntilThresholdRoundTest):
 
         test_round = CheckTransactionHistoryRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         self._complete_run(
@@ -739,12 +779,12 @@ class TestCheckTransactionHistoryRound(BaseCollectSameUntilThresholdRoundTest):
                     self.participants, expected_status, expected_tx_hash
                 ),
                 synchronized_data_update_fn=lambda synchronized_data, _: synchronized_data.update(
-                    participant_to_check=dict(
+                    participant_to_check=CollectionRound.serialize_collection(
                         get_participant_to_check(
                             self.participants, expected_status, expected_tx_hash
                         )
                     ),
-                    final_verification_status=VerificationStatus(int(expected_status)),
+                    final_verification_status=int(expected_status),
                     tx_hashes_history=[expected_tx_hash],
                     keepers=keepers,
                     final_tx_hash="0xb0e6add595e00477cf347d09797b156719dc5233283ac76e4efce2a674fe72d9",
@@ -778,8 +818,11 @@ class TestSynchronizeLateMessagesRound(BaseCollectNonEmptyUntilThresholdRound):
     @pytest.mark.parametrize(
         "missed_messages, expected_event",
         (
-            (0, TransactionSettlementEvent.MISSED_AND_LATE_MESSAGES_MISMATCH),
-            (8, TransactionSettlementEvent.DONE),
+            (
+                {f"agent_{i}": 0 for i in range(4)},
+                TransactionSettlementEvent.SUSPICIOUS_ACTIVITY,
+            ),
+            ({f"agent_{i}": 2 for i in range(4)}, TransactionSettlementEvent.DONE),
         ),
     )
     def test_runs(
@@ -789,8 +832,12 @@ class TestSynchronizeLateMessagesRound(BaseCollectNonEmptyUntilThresholdRound):
         self.synchronized_data.update(missed_messages=missed_messages)
         test_round = SynchronizeLateMessagesRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
+        late_arriving_tx_hashes = {
+            p: "".join(("1" * TX_HASH_LENGTH, "2" * TX_HASH_LENGTH))
+            for p in self.participants
+        }
+        test_round.required_block_confirmations = 0
         self._complete_run(
             self._test_round(
                 test_round=test_round,
@@ -798,27 +845,37 @@ class TestSynchronizeLateMessagesRound(BaseCollectNonEmptyUntilThresholdRound):
                     self.participants
                 ),
                 synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.update(
-                    late_arriving_tx_hashes=["1" * TX_HASH_LENGTH, "2" * TX_HASH_LENGTH]
-                    * len(self.participants)
+                    late_arriving_tx_hashes=late_arriving_tx_hashes,
+                    suspects=tuple()
+                    if expected_event == TransactionSettlementEvent.DONE
+                    else tuple(sorted(late_arriving_tx_hashes.keys())),
                 ),
                 synchronized_data_attr_checks=[
-                    lambda _synchronized_data: _synchronized_data.late_arriving_tx_hashes
+                    lambda _synchronized_data: _synchronized_data.late_arriving_tx_hashes,
+                    lambda _synchronized_data: _synchronized_data.suspects,
                 ],
                 exit_event=expected_event,
             )
         )
 
-    def test_incorrect_serialization_not_accepted(self) -> None:
-        """Test wrong serialization not collected"""
+    @pytest.mark.parametrize("correct_serialization", (True, False))
+    def test_check_payload(self, correct_serialization: bool) -> None:
+        """Test the `check_payload` method."""
 
         test_round = SynchronizeLateMessagesRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
         sender = list(test_round.accepting_payloads_from).pop()
-        tx_hashes = "0" * (TX_HASH_LENGTH - 1)
+        hash_length = TX_HASH_LENGTH
+        if not correct_serialization:
+            hash_length -= 1
+        tx_hashes = "0" * hash_length
         payload = SynchronizeLateMessagesPayload(sender=sender, tx_hashes=tx_hashes)
 
+        if correct_serialization:
+            test_round.check_payload(payload)
+            return
+
         with pytest.raises(
             TransactionNotValidError, match="Expecting serialized data of chunk size"
         ):
@@ -836,14 +893,24 @@ def test_synchronized_datas() -> None:
 
     participants = get_participants()
     participant_to_randomness = get_participant_to_randomness(participants, 1)
+    participant_to_randomness_serialized = CollectionRound.serialize_collection(
+        participant_to_randomness
+    )
     most_voted_randomness = get_most_voted_randomness()
     participant_to_selection = get_participant_to_selection(participants, "test")
+    participant_to_selection_serialized = CollectionRound.serialize_collection(
+        participant_to_selection
+    )
     safe_contract_address = get_safe_contract_address()
     most_voted_tx_hash = get_most_voted_tx_hash()
     participant_to_signature = get_participant_to_signature(participants)
+    participant_to_signature_serialized = CollectionRound.serialize_collection(
+        participant_to_signature
+    )
     final_tx_hash = get_final_tx_hash()
     actual_keeper_randomness = int(most_voted_randomness, base=16) / MAX_INT_256
-    late_arriving_tx_hashes = get_late_arriving_tx_hashes()
+    late_arriving_tx_hashes_serialized = get_late_arriving_tx_hashes_serialized()
+    late_arriving_tx_hashes_deserialized = get_late_arriving_tx_hashes_deserialized()
     keepers = get_keepers(deque(("agent_1" + "-" * 35, "agent_3" + "-" * 35)))
     expected_keepers = deque(["agent_1" + "-" * 35, "agent_3" + "-" * 35])
 
@@ -858,15 +925,15 @@ def test_synchronized_datas() -> None:
         AbciAppDB(
             setup_data=AbciAppDB.data_to_lists(
                 dict(
-                    participants=participants,
-                    participant_to_randomness=participant_to_randomness,
+                    participants=tuple(participants),
+                    participant_to_randomness=participant_to_randomness_serialized,
                     most_voted_randomness=most_voted_randomness,
-                    participant_to_selection=participant_to_selection,
+                    participant_to_selection=participant_to_selection_serialized,
                     safe_contract_address=safe_contract_address,
                     most_voted_tx_hash=most_voted_tx_hash,
-                    participant_to_signature=participant_to_signature,
+                    participant_to_signature=participant_to_signature_serialized,
                     final_tx_hash=final_tx_hash,
-                    late_arriving_tx_hashes=late_arriving_tx_hashes,
+                    late_arriving_tx_hashes=late_arriving_tx_hashes_serialized,
                     keepers=keepers,
                     blacklisted_keepers="t" * 42,
                 )
@@ -879,9 +946,14 @@ def test_synchronized_datas() -> None:
     assert synchronized_data_____.most_voted_randomness == most_voted_randomness
     assert synchronized_data_____.safe_contract_address == safe_contract_address
     assert synchronized_data_____.most_voted_tx_hash == most_voted_tx_hash
+    assert synchronized_data_____.participant_to_randomness == participant_to_randomness
+    assert synchronized_data_____.participant_to_selection == participant_to_selection
     assert synchronized_data_____.participant_to_signature == participant_to_signature
     assert synchronized_data_____.final_tx_hash == final_tx_hash
-    assert synchronized_data_____.late_arriving_tx_hashes == late_arriving_tx_hashes
+    assert (
+        synchronized_data_____.late_arriving_tx_hashes
+        == late_arriving_tx_hashes_deserialized
+    )
     assert synchronized_data_____.keepers == expected_keepers
     assert synchronized_data_____.keeper_retries == 1
     assert (
@@ -907,10 +979,8 @@ class TestResetRound(BaseCollectSameUntilThresholdRoundTest):
         synchronized_data = self.synchronized_data.update(
             keeper_randomness=DUMMY_RANDOMNESS,
         )
-        synchronized_data._db._cross_period_persisted_keys = ["keeper_randomness"]
-        test_round = ResetRound(
-            synchronized_data=synchronized_data, consensus_params=self.consensus_params
-        )
+        synchronized_data._db._cross_period_persisted_keys = {"keeper_randomness"}
+        test_round = ResetRound(synchronized_data=synchronized_data)
         next_period_count = 1
         self._complete_run(
             self._test_round(
@@ -919,8 +989,8 @@ class TestResetRound(BaseCollectSameUntilThresholdRoundTest):
                     self.participants, next_period_count
                 ),
                 synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.create(
-                    participants=[self.participants],
-                    all_participants=[self.participants],
+                    participants=[tuple(self.participants)],
+                    all_participants=[tuple(self.participants)],
                     keeper_randomness=[DUMMY_RANDOMNESS],
                 ),
                 synchronized_data_attr_checks=[],  # [lambda _synchronized_data: _synchronized_data.participants],
