@@ -210,3 +210,9 @@ DEPLOYED  # unused variable (open-autonomy/autonomy/chain/base.py:53)
 TERMINATED_BONDED  # unused variable (open-autonomy/autonomy/chain/base.py:54)
 contract  # unused function (open-autonomy/autonomy/cli/mint.py:106)
 directory  # unused attribute (open-autonomy/autonomy/cli/helpers/analyse.py:43)
+_check_dialogues  # unused function (open-autonomy/autonomy/cli/analyse.py:216)
+parse_file  # unused function (open-autonomy/autonomy/analyse/abci/logs.py:53)
+n_agents  # unused attribute (open-autonomy/autonomy/analyse/logs/collection.py:48)
+insert_one  # unused method (open-autonomy/autonomy/analyse/logs/db.py:143)
+_parse_logs  # unused function (open-autonomy/autonomy/cli/analyse.py:165)
+_check_service  # unused function (open-autonomy/autonomy/cli/analyse.py:289)
