@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -26,13 +26,14 @@ from typing import Dict, List, Tuple
 from unittest import mock
 
 import yaml
+from aea.cli.utils.config import get_default_author_from_cli_config
 from aea.configurations.constants import PACKAGES
 from aea_test_autonomy.configurations import (
     ETHEREUM_ENCRYPTED_KEYS,
     ETHEREUM_ENCRYPTION_PASSWORD,
 )
 
-from autonomy.constants import DEFAULT_BUILD_FOLDER
+from autonomy.constants import DEFAULT_BUILD_FOLDER, DEFAULT_DOCKER_IMAGE_AUTHOR
 from autonomy.deploy.constants import (
     DEBUG,
     DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA,
@@ -135,6 +136,8 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
         assert result.exit_code == 0, result.output
         assert build_dir.exists()
 
+        assert not (build_dir / "nodes").exists()
+
         self.check_docker_compose_build(
             build_dir=build_dir,
         )
@@ -142,6 +145,27 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
             path=build_dir / DockerComposeGenerator.output_name
         )
 
+    def test_docker_compose_build_with_testnet(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--force",
+                    "--local",
+                    "--local-tm-setup",
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert (build_dir / "nodes").exists()
+
     def test_docker_compose_build_log_level(
         self,
     ) -> None:
@@ -354,6 +378,79 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                 rmtree_mock.assert_called_once()
                 assert str(side_effect) in result.stdout
 
+    def test_docker_compose_build_image_author_flag_default(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--force",
+                    "--local",
+                    "--log-level",
+                    DEBUG,
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_docker_compose_build(
+            build_dir=build_dir,
+        )
+
+        docker_compose = self.load_and_check_docker_compose_file(
+            path=build_dir / DockerComposeGenerator.output_name
+        )
+
+        assert (
+            docker_compose["services"]["abci0"]["image"].split("/")[0]
+            == get_default_author_from_cli_config()
+            or DEFAULT_DOCKER_IMAGE_AUTHOR
+        )
+
+    def test_docker_compose_build_image_author_flag_custom(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        image_author = "some_author"
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--force",
+                    "--local",
+                    "--log-level",
+                    DEBUG,
+                    "--image-author",
+                    image_author,
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_docker_compose_build(
+            build_dir=build_dir,
+        )
+
+        docker_compose = self.load_and_check_docker_compose_file(
+            path=build_dir / DockerComposeGenerator.output_name
+        )
+
+        assert (
+            docker_compose["services"]["abci0"]["image"].split("/")[0] == image_author
+        )
+
 
 class TestKubernetesBuild(BaseDeployBuildTest):
     """Test kubernetes builds."""
@@ -367,8 +464,8 @@ class TestKubernetesBuild(BaseDeployBuildTest):
         with open(path / "build.yaml", "r") as fp:
             return list(yaml.safe_load_all(fp))
 
-    @staticmethod
-    def check_kubernetes_build(build_dir: Path) -> None:
+    @classmethod
+    def check_kubernetes_build(cls, build_dir: Path) -> None:
         """Check kubernetes build dir."""
 
         build_tree = list(map(lambda x: x.name, build_dir.iterdir()))
@@ -376,6 +473,14 @@ class TestKubernetesBuild(BaseDeployBuildTest):
             child in build_tree for child in ["persistent_storage", "build.yaml"]
         )
 
+        kubernetes_config = cls.load_kubernetes_config(path=build_dir)
+        assert all(
+            [
+                resource["metadata"]["name"] != "config-nodes"
+                for resource in kubernetes_config
+            ]
+        )
+
     def test_kubernetes_build(
         self,
     ) -> None:
@@ -397,10 +502,7 @@ class TestKubernetesBuild(BaseDeployBuildTest):
         assert result.exit_code == 0, result.output
         assert build_dir.exists()
 
-        build_tree = list(map(lambda x: x.name, build_dir.iterdir()))
-        assert any(
-            child in build_tree for child in ["persistent_storage", "build.yaml"]
-        )
+        self.check_kubernetes_build(build_dir=build_dir)
 
     def test_kubernetes_build_log_level(
         self,
@@ -508,3 +610,99 @@ class TestKubernetesBuild(BaseDeployBuildTest):
             ).exists()
             for i in range(4)
         )
+
+    def test_kubernetes_build_with_testnet(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--force",
+                    "--local",
+                    "--kubernetes",
+                    "--local-tm-setup",
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+
+        kubernetes_config = self.load_kubernetes_config(
+            path=build_dir,
+        )
+
+        assert any(
+            [
+                resource["metadata"]["name"] == "config-nodes"
+                for resource in kubernetes_config
+            ]
+        )
+
+    def test_kubernetes_build_image_author_default(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--kubernetes",
+                    "--force",
+                    "--local",
+                    "--log-level",
+                    DEBUG,
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_kubernetes_build(build_dir=build_dir)
+
+        build_config = self.load_kubernetes_config(build_dir)
+        assert (
+            f"'image': '{get_default_author_from_cli_config() or  DEFAULT_DOCKER_IMAGE_AUTHOR}/oar-"
+            in str(build_config)
+        )
+
+    def test_kubernetes_build_image_author_custom(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        image_author = "some_image_author"
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--kubernetes",
+                    "--force",
+                    "--local",
+                    "--log-level",
+                    DEBUG,
+                    "--image-author",
+                    image_author,
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_kubernetes_build(build_dir=build_dir)
+
+        build_config = self.load_kubernetes_config(build_dir)
+        assert f"'image': '{image_author}/oar-" in str(build_config)
+        assert f"'image': '{DEFAULT_DOCKER_IMAGE_AUTHOR}/oar-" not in str(build_config)
